/*
 * Automatically generated C config: don't edit
 * Linux kernel version: 2.6.17.13
 * Sat Sep  9 00:43:47 2006
 */
#define AUTOCONF_INCLUDED
#define CONFIG_X86_32 1
#define CONFIG_SEMAPHORE_SLEEPERS 1
#define CONFIG_X86 1
#define CONFIG_MMU 1
#define CONFIG_GENERIC_ISA_DMA 1
#define CONFIG_GENERIC_IOMAP 1
#define CONFIG_GENERIC_HWEIGHT 1
#define CONFIG_ARCH_MAY_HAVE_PC_FDC 1
#define CONFIG_DMI 1

/*
 * Code maturity level options
 */
#define CONFIG_EXPERIMENTAL 1
#define CONFIG_BROKEN_ON_SMP 1
#define CONFIG_INIT_ENV_ARG_LIMIT 32

/*
 * General setup
 */
#define CONFIG_LOCALVERSION ""
#undef CONFIG_LOCALVERSION_AUTO
#define CONFIG_SWAP 1
#define CONFIG_SYSVIPC 1
#define CONFIG_POSIX_MQUEUE 1
#define CONFIG_BSD_PROCESS_ACCT 1
#undef CONFIG_BSD_PROCESS_ACCT_V3
#define CONFIG_SYSCTL 1
#undef CONFIG_AUDIT
#define CONFIG_IKCONFIG 1
#define CONFIG_IKCONFIG_PROC 1
#undef CONFIG_RELAY
#define CONFIG_INITRAMFS_SOURCE ""
#define CONFIG_UID16 1
#define CONFIG_VM86 1
#undef CONFIG_CC_OPTIMIZE_FOR_SIZE
#undef CONFIG_EMBEDDED
#define CONFIG_KALLSYMS 1
#undef CONFIG_KALLSYMS_EXTRA_PASS
#define CONFIG_HOTPLUG 1
#define CONFIG_PRINTK 1
#define CONFIG_BUG 1
#define CONFIG_ELF_CORE 1
#define CONFIG_BASE_FULL 1
#define CONFIG_FUTEX 1
#define CONFIG_EPOLL 1
#define CONFIG_SHMEM 1
#define CONFIG_SLAB 1
#undef CONFIG_TINY_SHMEM
#define CONFIG_BASE_SMALL 0
#undef CONFIG_SLOB

/*
 * Loadable module support
 */
#define CONFIG_MODULES 1
#define CONFIG_MODULE_UNLOAD 1
#undef CONFIG_MODULE_FORCE_UNLOAD
#undef CONFIG_MODVERSIONS
#undef CONFIG_MODULE_SRCVERSION_ALL
#define CONFIG_KMOD 1

/*
 * Block layer
 */
#define CONFIG_LBD 1
#undef CONFIG_BLK_DEV_IO_TRACE
#define CONFIG_LSF 1

/*
 * IO Schedulers
 */
#define CONFIG_IOSCHED_NOOP 1
#define CONFIG_IOSCHED_AS 1
#define CONFIG_IOSCHED_DEADLINE 1
#define CONFIG_IOSCHED_CFQ 1
#define CONFIG_DEFAULT_AS 1
#undef CONFIG_DEFAULT_DEADLINE
#undef CONFIG_DEFAULT_CFQ
#undef CONFIG_DEFAULT_NOOP
#define CONFIG_DEFAULT_IOSCHED "anticipatory"

/*
 * Processor type and features
 */
#undef CONFIG_SMP
#define CONFIG_X86_PC 1
#undef CONFIG_X86_ELAN
#undef CONFIG_X86_VOYAGER
#undef CONFIG_X86_NUMAQ
#undef CONFIG_X86_SUMMIT
#undef CONFIG_X86_BIGSMP
#undef CONFIG_X86_VISWS
#undef CONFIG_X86_GENERICARCH
#undef CONFIG_X86_ES7000
#undef CONFIG_M386
#define CONFIG_M486 1
#undef CONFIG_M586
#undef CONFIG_M586TSC
#undef CONFIG_M586MMX
#undef CONFIG_M686
#undef CONFIG_MPENTIUMII
#undef CONFIG_MPENTIUMIII
#undef CONFIG_MPENTIUMM
#undef CONFIG_MPENTIUM4
#undef CONFIG_MK6
#undef CONFIG_MK7
#undef CONFIG_MK8
#undef CONFIG_MCRUSOE
#undef CONFIG_MEFFICEON
#undef CONFIG_MWINCHIPC6
#undef CONFIG_MWINCHIP2
#undef CONFIG_MWINCHIP3D
#undef CONFIG_MGEODEGX1
#undef CONFIG_MGEODE_LX
#undef CONFIG_MCYRIXIII
#undef CONFIG_MVIAC3_2
#define CONFIG_X86_GENERIC 1
#define CONFIG_X86_CMPXCHG 1
#define CONFIG_X86_XADD 1
#define CONFIG_X86_L1_CACHE_SHIFT 7
#define CONFIG_RWSEM_XCHGADD_ALGORITHM 1
#define CONFIG_GENERIC_CALIBRATE_DELAY 1
#define CONFIG_X86_PPRO_FENCE 1
#define CONFIG_X86_F00F_BUG 1
#define CONFIG_X86_WP_WORKS_OK 1
#define CONFIG_X86_INVLPG 1
#define CONFIG_X86_BSWAP 1
#define CONFIG_X86_POPAD_OK 1
#define CONFIG_X86_ALIGNMENT_16 1
#define CONFIG_X86_INTEL_USERCOPY 1
#define CONFIG_HPET_TIMER 1
#define CONFIG_HPET_EMULATE_RTC 1
#define CONFIG_PREEMPT_NONE 1
#undef CONFIG_PREEMPT_VOLUNTARY
#undef CONFIG_PREEMPT
#undef CONFIG_X86_UP_APIC
#define CONFIG_X86_MCE 1
#define CONFIG_X86_MCE_NONFATAL_MODULE 1
#define CONFIG_TOSHIBA_MODULE 1
#define CONFIG_I8K_MODULE 1
#define CONFIG_X86_REBOOTFIXUPS 1
#define CONFIG_MICROCODE_MODULE 1
#define CONFIG_X86_MSR_MODULE 1
#define CONFIG_X86_CPUID_MODULE 1

/*
 * Firmware Drivers
 */
#define CONFIG_EDD_MODULE 1
#define CONFIG_DELL_RBU_MODULE 1
#define CONFIG_DCDBAS_MODULE 1
#undef CONFIG_NOHIGHMEM
#define CONFIG_HIGHMEM4G 1
#undef CONFIG_HIGHMEM64G
#define CONFIG_PAGE_OFFSET 0xC0000000
#define CONFIG_HIGHMEM 1
#define CONFIG_ARCH_FLATMEM_ENABLE 1
#define CONFIG_ARCH_SPARSEMEM_ENABLE 1
#define CONFIG_ARCH_SELECT_MEMORY_MODEL 1
#define CONFIG_SELECT_MEMORY_MODEL 1
#define CONFIG_FLATMEM_MANUAL 1
#undef CONFIG_DISCONTIGMEM_MANUAL
#undef CONFIG_SPARSEMEM_MANUAL
#define CONFIG_FLATMEM 1
#define CONFIG_FLAT_NODE_MEM_MAP 1
#define CONFIG_SPARSEMEM_STATIC 1
#define CONFIG_SPLIT_PTLOCK_CPUS 4
#define CONFIG_HIGHPTE 1
#define CONFIG_MATH_EMULATION 1
#define CONFIG_MTRR 1
#undef CONFIG_EFI
#undef CONFIG_REGPARM
#define CONFIG_SECCOMP 1
#undef CONFIG_HZ_100
#define CONFIG_HZ_250 1
#undef CONFIG_HZ_1000
#define CONFIG_HZ 250
#undef CONFIG_KEXEC
#undef CONFIG_CRASH_DUMP
#define CONFIG_PHYSICAL_START 0x100000
#define CONFIG_ARCH_ENABLE_MEMORY_HOTPLUG 1

/*
 * Power management options (ACPI, APM)
 */
#define CONFIG_PM 1
#define CONFIG_PM_LEGACY 1
#undef CONFIG_PM_DEBUG
#undef CONFIG_SOFTWARE_SUSPEND

/*
 * ACPI (Advanced Configuration and Power Interface) Support
 */
#define CONFIG_ACPI 1
#define CONFIG_ACPI_SLEEP 1
#define CONFIG_ACPI_SLEEP_PROC_FS 1
#undef CONFIG_ACPI_SLEEP_PROC_SLEEP
#define CONFIG_ACPI_AC_MODULE 1
#define CONFIG_ACPI_BATTERY_MODULE 1
#define CONFIG_ACPI_BUTTON_MODULE 1
#define CONFIG_ACPI_VIDEO_MODULE 1
#undef CONFIG_ACPI_HOTKEY
#define CONFIG_ACPI_FAN_MODULE 1
#define CONFIG_ACPI_PROCESSOR_MODULE 1
#define CONFIG_ACPI_THERMAL_MODULE 1
#define CONFIG_ACPI_ASUS_MODULE 1
#define CONFIG_ACPI_IBM_MODULE 1
#undef CONFIG_ACPI_IBM_DOCK
#define CONFIG_ACPI_TOSHIBA_MODULE 1
#define CONFIG_ACPI_BLACKLIST_YEAR 0
#undef CONFIG_ACPI_DEBUG
#define CONFIG_ACPI_EC 1
#define CONFIG_ACPI_POWER 1
#define CONFIG_ACPI_SYSTEM 1
#define CONFIG_X86_PM_TIMER 1
#define CONFIG_ACPI_CONTAINER_MODULE 1

/*
 * APM (Advanced Power Management) BIOS Support
 */
#define CONFIG_APM 1
#undef CONFIG_APM_IGNORE_USER_SUSPEND
#undef CONFIG_APM_DO_ENABLE
#undef CONFIG_APM_CPU_IDLE
#undef CONFIG_APM_DISPLAY_BLANK
#undef CONFIG_APM_RTC_IS_GMT
#undef CONFIG_APM_ALLOW_INTS
#undef CONFIG_APM_REAL_MODE_POWER_OFF

/*
 * CPU Frequency scaling
 */
#define CONFIG_CPU_FREQ 1
#define CONFIG_CPU_FREQ_TABLE_MODULE 1
#undef CONFIG_CPU_FREQ_DEBUG
#define CONFIG_CPU_FREQ_STAT_MODULE 1
#define CONFIG_CPU_FREQ_STAT_DETAILS 1
#undef CONFIG_CPU_FREQ_DEFAULT_GOV_PERFORMANCE
#define CONFIG_CPU_FREQ_DEFAULT_GOV_USERSPACE 1
#define CONFIG_CPU_FREQ_GOV_PERFORMANCE_MODULE 1
#define CONFIG_CPU_FREQ_GOV_POWERSAVE_MODULE 1
#define CONFIG_CPU_FREQ_GOV_USERSPACE 1
#define CONFIG_CPU_FREQ_GOV_ONDEMAND_MODULE 1
#define CONFIG_CPU_FREQ_GOV_CONSERVATIVE_MODULE 1

/*
 * CPUFreq processor drivers
 */
#define CONFIG_X86_ACPI_CPUFREQ_MODULE 1
#define CONFIG_X86_POWERNOW_K6_MODULE 1
#define CONFIG_X86_POWERNOW_K7_MODULE 1
#define CONFIG_X86_POWERNOW_K7_ACPI 1
#define CONFIG_X86_POWERNOW_K8_MODULE 1
#define CONFIG_X86_POWERNOW_K8_ACPI 1
#define CONFIG_X86_GX_SUSPMOD_MODULE 1
#define CONFIG_X86_SPEEDSTEP_CENTRINO_MODULE 1
#define CONFIG_X86_SPEEDSTEP_CENTRINO_ACPI 1
#define CONFIG_X86_SPEEDSTEP_CENTRINO_TABLE 1
#define CONFIG_X86_SPEEDSTEP_ICH_MODULE 1
#define CONFIG_X86_SPEEDSTEP_SMI_MODULE 1
#define CONFIG_X86_P4_CLOCKMOD_MODULE 1
#define CONFIG_X86_CPUFREQ_NFORCE2_MODULE 1
#define CONFIG_X86_LONGRUN_MODULE 1

/*
 * shared options
 */
#undef CONFIG_X86_ACPI_CPUFREQ_PROC_INTF
#define CONFIG_X86_SPEEDSTEP_LIB_MODULE 1
#define CONFIG_X86_SPEEDSTEP_RELAXED_CAP_CHECK 1

/*
 * Bus options (PCI, PCMCIA, EISA, MCA, ISA)
 */
#define CONFIG_PCI 1
#undef CONFIG_PCI_GOBIOS
#undef CONFIG_PCI_GOMMCONFIG
#undef CONFIG_PCI_GODIRECT
#define CONFIG_PCI_GOANY 1
#define CONFIG_PCI_BIOS 1
#define CONFIG_PCI_DIRECT 1
#define CONFIG_PCI_MMCONFIG 1
#define CONFIG_PCIEPORTBUS 1
#define CONFIG_HOTPLUG_PCI_PCIE_MODULE 1
#undef CONFIG_HOTPLUG_PCI_PCIE_POLL_EVENT_MODE
#define CONFIG_ISA_DMA_API 1
#define CONFIG_ISA 1
#undef CONFIG_EISA
#undef CONFIG_MCA
#define CONFIG_SCx200_MODULE 1

/*
 * PCCARD (PCMCIA/CardBus) support
 */
#define CONFIG_PCCARD_MODULE 1
#undef CONFIG_PCMCIA_DEBUG
#define CONFIG_PCMCIA_MODULE 1
#define CONFIG_PCMCIA_LOAD_CIS 1
#define CONFIG_PCMCIA_IOCTL 1
#define CONFIG_CARDBUS 1

/*
 * PC-card bridges
 */
#define CONFIG_YENTA_MODULE 1
#define CONFIG_YENTA_O2 1
#define CONFIG_YENTA_RICOH 1
#define CONFIG_YENTA_TI 1
#define CONFIG_YENTA_ENE_TUNE 1
#define CONFIG_YENTA_TOSHIBA 1
#define CONFIG_PD6729_MODULE 1
#define CONFIG_I82092_MODULE 1
#define CONFIG_I82365_MODULE 1
#define CONFIG_TCIC_MODULE 1
#define CONFIG_PCMCIA_PROBE 1
#define CONFIG_PCCARD_NONSTATIC_MODULE 1

/*
 * PCI Hotplug Support
 */
#define CONFIG_HOTPLUG_PCI 1
#define CONFIG_HOTPLUG_PCI_FAKE_MODULE 1
#define CONFIG_HOTPLUG_PCI_COMPAQ_MODULE 1
#undef CONFIG_HOTPLUG_PCI_COMPAQ_NVRAM
#define CONFIG_HOTPLUG_PCI_ACPI_MODULE 1
#define CONFIG_HOTPLUG_PCI_ACPI_IBM_MODULE 1
#undef CONFIG_HOTPLUG_PCI_CPCI
#define CONFIG_HOTPLUG_PCI_SHPC_MODULE 1
#undef CONFIG_HOTPLUG_PCI_SHPC_POLL_EVENT_MODE

/*
 * Executable file formats
 */
#define CONFIG_BINFMT_ELF 1
#define CONFIG_BINFMT_AOUT_MODULE 1
#define CONFIG_BINFMT_MISC_MODULE 1

/*
 * Networking
 */
#define CONFIG_NET 1

/*
 * Networking options
 */
#undef CONFIG_NETDEBUG
#define CONFIG_PACKET 1
#define CONFIG_PACKET_MMAP 1
#define CONFIG_UNIX 1
#define CONFIG_XFRM 1
#define CONFIG_XFRM_USER 1
#define CONFIG_NET_KEY_MODULE 1
#define CONFIG_INET 1
#define CONFIG_IP_MULTICAST 1
#define CONFIG_IP_ADVANCED_ROUTER 1
#define CONFIG_ASK_IP_FIB_HASH 1
#undef CONFIG_IP_FIB_TRIE
#define CONFIG_IP_FIB_HASH 1
#define CONFIG_IP_MULTIPLE_TABLES 1
#define CONFIG_IP_ROUTE_FWMARK 1
#define CONFIG_IP_ROUTE_MULTIPATH 1
#undef CONFIG_IP_ROUTE_MULTIPATH_CACHED
#define CONFIG_IP_ROUTE_VERBOSE 1
#undef CONFIG_IP_PNP
#define CONFIG_NET_IPIP_MODULE 1
#define CONFIG_NET_IPGRE_MODULE 1
#define CONFIG_NET_IPGRE_BROADCAST 1
#define CONFIG_IP_MROUTE 1
#define CONFIG_IP_PIMSM_V1 1
#define CONFIG_IP_PIMSM_V2 1
#undef CONFIG_ARPD
#define CONFIG_SYN_COOKIES 1
#define CONFIG_INET_AH_MODULE 1
#define CONFIG_INET_ESP_MODULE 1
#define CONFIG_INET_IPCOMP_MODULE 1
#define CONFIG_INET_XFRM_TUNNEL_MODULE 1
#define CONFIG_INET_TUNNEL_MODULE 1
#define CONFIG_INET_DIAG_MODULE 1
#define CONFIG_INET_TCP_DIAG_MODULE 1
#undef CONFIG_TCP_CONG_ADVANCED
#define CONFIG_TCP_CONG_BIC 1

/*
 * IP: Virtual Server Configuration
 */
#define CONFIG_IP_VS_MODULE 1
#undef CONFIG_IP_VS_DEBUG
#define CONFIG_IP_VS_TAB_BITS 12

/*
 * IPVS transport protocol load balancing support
 */
#define CONFIG_IP_VS_PROTO_TCP 1
#define CONFIG_IP_VS_PROTO_UDP 1
#define CONFIG_IP_VS_PROTO_ESP 1
#define CONFIG_IP_VS_PROTO_AH 1

/*
 * IPVS scheduler
 */
#define CONFIG_IP_VS_RR_MODULE 1
#define CONFIG_IP_VS_WRR_MODULE 1
#define CONFIG_IP_VS_LC_MODULE 1
#define CONFIG_IP_VS_WLC_MODULE 1
#define CONFIG_IP_VS_LBLC_MODULE 1
#define CONFIG_IP_VS_LBLCR_MODULE 1
#define CONFIG_IP_VS_DH_MODULE 1
#define CONFIG_IP_VS_SH_MODULE 1
#define CONFIG_IP_VS_SED_MODULE 1
#define CONFIG_IP_VS_NQ_MODULE 1

/*
 * IPVS application helper
 */
#define CONFIG_IP_VS_FTP_MODULE 1
#define CONFIG_IPV6_MODULE 1
#define CONFIG_IPV6_PRIVACY 1
#undef CONFIG_IPV6_ROUTER_PREF
#define CONFIG_INET6_AH_MODULE 1
#define CONFIG_INET6_ESP_MODULE 1
#define CONFIG_INET6_IPCOMP_MODULE 1
#define CONFIG_INET6_XFRM_TUNNEL_MODULE 1
#define CONFIG_INET6_TUNNEL_MODULE 1
#define CONFIG_IPV6_TUNNEL_MODULE 1
#define CONFIG_NETFILTER 1
#undef CONFIG_NETFILTER_DEBUG
#define CONFIG_BRIDGE_NETFILTER 1

/*
 * Core Netfilter Configuration
 */
#define CONFIG_NETFILTER_NETLINK_MODULE 1
#define CONFIG_NETFILTER_NETLINK_QUEUE_MODULE 1
#define CONFIG_NETFILTER_NETLINK_LOG_MODULE 1
#define CONFIG_NETFILTER_XTABLES_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_CLASSIFY_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_MARK_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_NFQUEUE_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_NOTRACK_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_COMMENT_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_CONNTRACK_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_DCCP_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_ESP_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_HELPER_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_LENGTH_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_LIMIT_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_MAC_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_MARK_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_POLICY_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_MULTIPORT_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_PHYSDEV_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_PKTTYPE_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_REALM_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_SCTP_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_STATE_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_STRING_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_TCPMSS_MODULE 1

/*
 * IP: Netfilter Configuration
 */
#define CONFIG_IP_NF_CONNTRACK_MODULE 1
#undef CONFIG_IP_NF_CT_ACCT
#undef CONFIG_IP_NF_CONNTRACK_MARK
#undef CONFIG_IP_NF_CONNTRACK_EVENTS
#define CONFIG_IP_NF_CONNTRACK_NETLINK_MODULE 1
#define CONFIG_IP_NF_CT_PROTO_SCTP_MODULE 1
#define CONFIG_IP_NF_FTP_MODULE 1
#define CONFIG_IP_NF_IRC_MODULE 1
#define CONFIG_IP_NF_NETBIOS_NS_MODULE 1
#define CONFIG_IP_NF_TFTP_MODULE 1
#define CONFIG_IP_NF_AMANDA_MODULE 1
#define CONFIG_IP_NF_PPTP_MODULE 1
#define CONFIG_IP_NF_H323_MODULE 1
#define CONFIG_IP_NF_QUEUE_MODULE 1
#define CONFIG_IP_NF_IPTABLES_MODULE 1
#define CONFIG_IP_NF_MATCH_IPRANGE_MODULE 1
#define CONFIG_IP_NF_MATCH_TOS_MODULE 1
#define CONFIG_IP_NF_MATCH_RECENT_MODULE 1
#define CONFIG_IP_NF_MATCH_ECN_MODULE 1
#define CONFIG_IP_NF_MATCH_DSCP_MODULE 1
#define CONFIG_IP_NF_MATCH_AH_MODULE 1
#define CONFIG_IP_NF_MATCH_TTL_MODULE 1
#define CONFIG_IP_NF_MATCH_OWNER_MODULE 1
#define CONFIG_IP_NF_MATCH_ADDRTYPE_MODULE 1
#define CONFIG_IP_NF_MATCH_HASHLIMIT_MODULE 1
#define CONFIG_IP_NF_FILTER_MODULE 1
#define CONFIG_IP_NF_TARGET_REJECT_MODULE 1
#define CONFIG_IP_NF_TARGET_LOG_MODULE 1
#define CONFIG_IP_NF_TARGET_ULOG_MODULE 1
#define CONFIG_IP_NF_TARGET_TCPMSS_MODULE 1
#define CONFIG_IP_NF_NAT_MODULE 1
#define CONFIG_IP_NF_NAT_NEEDED 1
#define CONFIG_IP_NF_TARGET_MASQUERADE_MODULE 1
#define CONFIG_IP_NF_TARGET_REDIRECT_MODULE 1
#define CONFIG_IP_NF_TARGET_NETMAP_MODULE 1
#define CONFIG_IP_NF_TARGET_SAME_MODULE 1
#define CONFIG_IP_NF_NAT_SNMP_BASIC_MODULE 1
#define CONFIG_IP_NF_NAT_IRC_MODULE 1
#define CONFIG_IP_NF_NAT_FTP_MODULE 1
#define CONFIG_IP_NF_NAT_TFTP_MODULE 1
#define CONFIG_IP_NF_NAT_AMANDA_MODULE 1
#define CONFIG_IP_NF_NAT_PPTP_MODULE 1
#define CONFIG_IP_NF_NAT_H323_MODULE 1
#define CONFIG_IP_NF_MANGLE_MODULE 1
#define CONFIG_IP_NF_TARGET_TOS_MODULE 1
#define CONFIG_IP_NF_TARGET_ECN_MODULE 1
#define CONFIG_IP_NF_TARGET_DSCP_MODULE 1
#define CONFIG_IP_NF_TARGET_TTL_MODULE 1
#define CONFIG_IP_NF_RAW_MODULE 1
#define CONFIG_IP_NF_ARPTABLES_MODULE 1
#define CONFIG_IP_NF_ARPFILTER_MODULE 1
#define CONFIG_IP_NF_ARP_MANGLE_MODULE 1

/*
 * IPv6: Netfilter Configuration (EXPERIMENTAL)
 */
#define CONFIG_IP6_NF_QUEUE_MODULE 1
#define CONFIG_IP6_NF_IPTABLES_MODULE 1
#define CONFIG_IP6_NF_MATCH_RT_MODULE 1
#define CONFIG_IP6_NF_MATCH_OPTS_MODULE 1
#define CONFIG_IP6_NF_MATCH_FRAG_MODULE 1
#define CONFIG_IP6_NF_MATCH_HL_MODULE 1
#define CONFIG_IP6_NF_MATCH_OWNER_MODULE 1
#define CONFIG_IP6_NF_MATCH_IPV6HEADER_MODULE 1
#define CONFIG_IP6_NF_MATCH_AH_MODULE 1
#define CONFIG_IP6_NF_MATCH_EUI64_MODULE 1
#define CONFIG_IP6_NF_FILTER_MODULE 1
#define CONFIG_IP6_NF_TARGET_LOG_MODULE 1
#define CONFIG_IP6_NF_TARGET_REJECT_MODULE 1
#define CONFIG_IP6_NF_MANGLE_MODULE 1
#define CONFIG_IP6_NF_TARGET_HL_MODULE 1
#define CONFIG_IP6_NF_RAW_MODULE 1

/*
 * Bridge: Netfilter Configuration
 */
#define CONFIG_BRIDGE_NF_EBTABLES_MODULE 1
#define CONFIG_BRIDGE_EBT_BROUTE_MODULE 1
#define CONFIG_BRIDGE_EBT_T_FILTER_MODULE 1
#define CONFIG_BRIDGE_EBT_T_NAT_MODULE 1
#define CONFIG_BRIDGE_EBT_802_3_MODULE 1
#define CONFIG_BRIDGE_EBT_AMONG_MODULE 1
#define CONFIG_BRIDGE_EBT_ARP_MODULE 1
#define CONFIG_BRIDGE_EBT_IP_MODULE 1
#define CONFIG_BRIDGE_EBT_LIMIT_MODULE 1
#define CONFIG_BRIDGE_EBT_MARK_MODULE 1
#define CONFIG_BRIDGE_EBT_PKTTYPE_MODULE 1
#define CONFIG_BRIDGE_EBT_STP_MODULE 1
#define CONFIG_BRIDGE_EBT_VLAN_MODULE 1
#define CONFIG_BRIDGE_EBT_ARPREPLY_MODULE 1
#define CONFIG_BRIDGE_EBT_DNAT_MODULE 1
#define CONFIG_BRIDGE_EBT_MARK_T_MODULE 1
#define CONFIG_BRIDGE_EBT_REDIRECT_MODULE 1
#define CONFIG_BRIDGE_EBT_SNAT_MODULE 1
#define CONFIG_BRIDGE_EBT_LOG_MODULE 1
#define CONFIG_BRIDGE_EBT_ULOG_MODULE 1

/*
 * DCCP Configuration (EXPERIMENTAL)
 */
#undef CONFIG_IP_DCCP

/*
 * SCTP Configuration (EXPERIMENTAL)
 */
#define CONFIG_IP_SCTP_MODULE 1
#undef CONFIG_SCTP_DBG_MSG
#undef CONFIG_SCTP_DBG_OBJCNT
#undef CONFIG_SCTP_HMAC_NONE
#undef CONFIG_SCTP_HMAC_SHA1
#define CONFIG_SCTP_HMAC_MD5 1

/*
 * TIPC Configuration (EXPERIMENTAL)
 */
#undef CONFIG_TIPC
#define CONFIG_ATM_MODULE 1
#define CONFIG_ATM_CLIP_MODULE 1
#undef CONFIG_ATM_CLIP_NO_ICMP
#define CONFIG_ATM_LANE_MODULE 1
#define CONFIG_ATM_MPOA_MODULE 1
#define CONFIG_ATM_BR2684_MODULE 1
#undef CONFIG_ATM_BR2684_IPFILTER
#define CONFIG_BRIDGE_MODULE 1
#define CONFIG_VLAN_8021Q_MODULE 1
#undef CONFIG_DECNET
#define CONFIG_LLC 1
#define CONFIG_LLC2_MODULE 1
#define CONFIG_IPX_MODULE 1
#undef CONFIG_IPX_INTERN
#define CONFIG_ATALK_MODULE 1
#define CONFIG_DEV_APPLETALK 1
#define CONFIG_LTPC_MODULE 1
#define CONFIG_COPS_MODULE 1
#define CONFIG_COPS_DAYNA 1
#define CONFIG_COPS_TANGENT 1
#define CONFIG_IPDDP_MODULE 1
#define CONFIG_IPDDP_ENCAP 1
#define CONFIG_IPDDP_DECAP 1
#undef CONFIG_X25
#undef CONFIG_LAPB
#define CONFIG_NET_DIVERT 1
#undef CONFIG_ECONET
#define CONFIG_WAN_ROUTER_MODULE 1

/*
 * QoS and/or fair queueing
 */
#define CONFIG_NET_SCHED 1
#define CONFIG_NET_SCH_CLK_JIFFIES 1
#undef CONFIG_NET_SCH_CLK_GETTIMEOFDAY
#undef CONFIG_NET_SCH_CLK_CPU

/*
 * Queueing/Scheduling
 */
#define CONFIG_NET_SCH_CBQ_MODULE 1
#define CONFIG_NET_SCH_HTB_MODULE 1
#define CONFIG_NET_SCH_HFSC_MODULE 1
#define CONFIG_NET_SCH_ATM_MODULE 1
#define CONFIG_NET_SCH_PRIO_MODULE 1
#define CONFIG_NET_SCH_RED_MODULE 1
#define CONFIG_NET_SCH_SFQ_MODULE 1
#define CONFIG_NET_SCH_TEQL_MODULE 1
#define CONFIG_NET_SCH_TBF_MODULE 1
#define CONFIG_NET_SCH_GRED_MODULE 1
#define CONFIG_NET_SCH_DSMARK_MODULE 1
#define CONFIG_NET_SCH_NETEM_MODULE 1
#define CONFIG_NET_SCH_INGRESS_MODULE 1

/*
 * Classification
 */
#define CONFIG_NET_CLS 1
#define CONFIG_NET_CLS_BASIC_MODULE 1
#define CONFIG_NET_CLS_TCINDEX_MODULE 1
#define CONFIG_NET_CLS_ROUTE4_MODULE 1
#define CONFIG_NET_CLS_ROUTE 1
#define CONFIG_NET_CLS_FW_MODULE 1
#define CONFIG_NET_CLS_U32_MODULE 1
#undef CONFIG_CLS_U32_PERF
#define CONFIG_CLS_U32_MARK 1
#define CONFIG_NET_CLS_RSVP_MODULE 1
#define CONFIG_NET_CLS_RSVP6_MODULE 1
#undef CONFIG_NET_EMATCH
#undef CONFIG_NET_CLS_ACT
#define CONFIG_NET_CLS_POLICE 1
#undef CONFIG_NET_CLS_IND
#define CONFIG_NET_ESTIMATOR 1

/*
 * Network testing
 */
#undef CONFIG_NET_PKTGEN
#define CONFIG_HAMRADIO 1

/*
 * Packet Radio protocols
 */
#define CONFIG_AX25_MODULE 1
#undef CONFIG_AX25_DAMA_SLAVE
#define CONFIG_NETROM_MODULE 1
#define CONFIG_ROSE_MODULE 1

/*
 * AX.25 network device drivers
 */
#define CONFIG_MKISS_MODULE 1
#define CONFIG_6PACK_MODULE 1
#define CONFIG_BPQETHER_MODULE 1
#define CONFIG_DMASCC_MODULE 1
#define CONFIG_SCC_MODULE 1
#define CONFIG_SCC_DELAY 1
#define CONFIG_SCC_TRXECHO 1
#define CONFIG_BAYCOM_SER_FDX_MODULE 1
#define CONFIG_BAYCOM_SER_HDX_MODULE 1
#define CONFIG_BAYCOM_PAR_MODULE 1
#define CONFIG_BAYCOM_EPP_MODULE 1
#define CONFIG_YAM_MODULE 1
#define CONFIG_IRDA_MODULE 1

/*
 * IrDA protocols
 */
#define CONFIG_IRLAN_MODULE 1
#define CONFIG_IRNET_MODULE 1
#define CONFIG_IRCOMM_MODULE 1
#undef CONFIG_IRDA_ULTRA

/*
 * IrDA options
 */
#define CONFIG_IRDA_CACHE_LAST_LSAP 1
#define CONFIG_IRDA_FAST_RR 1
#undef CONFIG_IRDA_DEBUG

/*
 * Infrared-port device drivers
 */

/*
 * SIR device drivers
 */
#define CONFIG_IRTTY_SIR_MODULE 1

/*
 * Dongle support
 */
#define CONFIG_DONGLE 1
#define CONFIG_ESI_DONGLE_MODULE 1
#define CONFIG_ACTISYS_DONGLE_MODULE 1
#define CONFIG_TEKRAM_DONGLE_MODULE 1
#define CONFIG_TOIM3232_DONGLE_MODULE 1
#define CONFIG_LITELINK_DONGLE_MODULE 1
#define CONFIG_MA600_DONGLE_MODULE 1
#define CONFIG_GIRBIL_DONGLE_MODULE 1
#define CONFIG_MCP2120_DONGLE_MODULE 1
#define CONFIG_OLD_BELKIN_DONGLE_MODULE 1
#define CONFIG_ACT200L_DONGLE_MODULE 1

/*
 * Old SIR device drivers
 */
#define CONFIG_IRPORT_SIR_MODULE 1

/*
 * Old Serial dongle support
 */
#undef CONFIG_DONGLE_OLD

/*
 * FIR device drivers
 */
#define CONFIG_USB_IRDA_MODULE 1
#define CONFIG_SIGMATEL_FIR_MODULE 1
#define CONFIG_NSC_FIR_MODULE 1
#define CONFIG_WINBOND_FIR_MODULE 1
#define CONFIG_TOSHIBA_FIR_MODULE 1
#define CONFIG_SMC_IRCC_FIR_MODULE 1
#define CONFIG_ALI_FIR_MODULE 1
#define CONFIG_VLSI_FIR_MODULE 1
#define CONFIG_VIA_FIR_MODULE 1
#define CONFIG_BT_MODULE 1
#define CONFIG_BT_L2CAP_MODULE 1
#define CONFIG_BT_SCO_MODULE 1
#define CONFIG_BT_RFCOMM_MODULE 1
#define CONFIG_BT_RFCOMM_TTY 1
#define CONFIG_BT_BNEP_MODULE 1
#define CONFIG_BT_BNEP_MC_FILTER 1
#define CONFIG_BT_BNEP_PROTO_FILTER 1
#define CONFIG_BT_CMTP_MODULE 1
#define CONFIG_BT_HIDP_MODULE 1

/*
 * Bluetooth device drivers
 */
#define CONFIG_BT_HCIUSB_MODULE 1
#define CONFIG_BT_HCIUSB_SCO 1
#define CONFIG_BT_HCIUART_MODULE 1
#define CONFIG_BT_HCIUART_H4 1
#define CONFIG_BT_HCIUART_BCSP 1
#define CONFIG_BT_HCIBCM203X_MODULE 1
#define CONFIG_BT_HCIBPA10X_MODULE 1
#define CONFIG_BT_HCIBFUSB_MODULE 1
#define CONFIG_BT_HCIDTL1_MODULE 1
#define CONFIG_BT_HCIBT3C_MODULE 1
#define CONFIG_BT_HCIBLUECARD_MODULE 1
#define CONFIG_BT_HCIBTUART_MODULE 1
#define CONFIG_BT_HCIVHCI_MODULE 1
#define CONFIG_IEEE80211_MODULE 1
#undef CONFIG_IEEE80211_DEBUG
#define CONFIG_IEEE80211_CRYPT_WEP_MODULE 1
#define CONFIG_IEEE80211_CRYPT_CCMP_MODULE 1
#define CONFIG_IEEE80211_CRYPT_TKIP_MODULE 1
#define CONFIG_IEEE80211_SOFTMAC_MODULE 1
#undef CONFIG_IEEE80211_SOFTMAC_DEBUG
#define CONFIG_WIRELESS_EXT 1

/*
 * Device Drivers
 */

/*
 * Generic Driver Options
 */
#define CONFIG_STANDALONE 1
#define CONFIG_PREVENT_FIRMWARE_BUILD 1
#define CONFIG_FW_LOADER_MODULE 1

/*
 * Connector - unified userspace <-> kernelspace linker
 */
#define CONFIG_CONNECTOR_MODULE 1

/*
 * Memory Technology Devices (MTD)
 */
#undef CONFIG_MTD

/*
 * Parallel port support
 */
#define CONFIG_PARPORT_MODULE 1
#define CONFIG_PARPORT_PC_MODULE 1
#define CONFIG_PARPORT_SERIAL_MODULE 1
#undef CONFIG_PARPORT_PC_FIFO
#undef CONFIG_PARPORT_PC_SUPERIO
#define CONFIG_PARPORT_PC_PCMCIA_MODULE 1
#define CONFIG_PARPORT_NOT_PC 1
#undef CONFIG_PARPORT_GSC
#define CONFIG_PARPORT_1284 1

/*
 * Plug and Play support
 */
#define CONFIG_PNP 1
#undef CONFIG_PNP_DEBUG

/*
 * Protocols
 */
#define CONFIG_ISAPNP 1
#undef CONFIG_PNPBIOS
#undef CONFIG_PNPACPI

/*
 * Block devices
 */
#define CONFIG_BLK_DEV_FD 1
#define CONFIG_BLK_DEV_XD_MODULE 1
#define CONFIG_PARIDE_MODULE 1
#define CONFIG_PARIDE_PARPORT_MODULE 1

/*
 * Parallel IDE high-level drivers
 */
#define CONFIG_PARIDE_PD_MODULE 1
#define CONFIG_PARIDE_PCD_MODULE 1
#define CONFIG_PARIDE_PF_MODULE 1
#define CONFIG_PARIDE_PT_MODULE 1
#define CONFIG_PARIDE_PG_MODULE 1

/*
 * Parallel IDE protocol modules
 */
#define CONFIG_PARIDE_ATEN_MODULE 1
#define CONFIG_PARIDE_BPCK_MODULE 1
#define CONFIG_PARIDE_BPCK6_MODULE 1
#define CONFIG_PARIDE_COMM_MODULE 1
#define CONFIG_PARIDE_DSTR_MODULE 1
#define CONFIG_PARIDE_FIT2_MODULE 1
#define CONFIG_PARIDE_FIT3_MODULE 1
#define CONFIG_PARIDE_EPAT_MODULE 1
#define CONFIG_PARIDE_EPATC8 1
#define CONFIG_PARIDE_EPIA_MODULE 1
#define CONFIG_PARIDE_FRIQ_MODULE 1
#define CONFIG_PARIDE_FRPW_MODULE 1
#define CONFIG_PARIDE_KBIC_MODULE 1
#define CONFIG_PARIDE_KTTI_MODULE 1
#define CONFIG_PARIDE_ON20_MODULE 1
#define CONFIG_PARIDE_ON26_MODULE 1
#define CONFIG_BLK_CPQ_DA_MODULE 1
#define CONFIG_BLK_CPQ_CISS_DA_MODULE 1
#define CONFIG_CISS_SCSI_TAPE 1
#define CONFIG_BLK_DEV_DAC960_MODULE 1
#define CONFIG_BLK_DEV_UMEM_MODULE 1
#undef CONFIG_BLK_DEV_COW_COMMON
#define CONFIG_BLK_DEV_LOOP 1
#define CONFIG_BLK_DEV_CRYPTOLOOP_MODULE 1
#define CONFIG_BLK_DEV_NBD_MODULE 1
#define CONFIG_BLK_DEV_SX8_MODULE 1
#undef CONFIG_BLK_DEV_UB
#define CONFIG_BLK_DEV_RAM 1
#define CONFIG_BLK_DEV_RAM_COUNT 16
#define CONFIG_BLK_DEV_RAM_SIZE 16384
#define CONFIG_BLK_DEV_INITRD 1
#define CONFIG_CDROM_PKTCDVD_MODULE 1
#define CONFIG_CDROM_PKTCDVD_BUFFERS 8
#undef CONFIG_CDROM_PKTCDVD_WCACHE
#define CONFIG_ATA_OVER_ETH_MODULE 1

/*
 * ATA/ATAPI/MFM/RLL support
 */
#define CONFIG_IDE 1
#define CONFIG_BLK_DEV_IDE 1

/*
 * Please see Documentation/ide.txt for help/info on IDE drives
 */
#undef CONFIG_BLK_DEV_IDE_SATA
#undef CONFIG_BLK_DEV_HD_IDE
#define CONFIG_BLK_DEV_IDEDISK 1
#undef CONFIG_IDEDISK_MULTI_MODE
#define CONFIG_BLK_DEV_IDECS_MODULE 1
#define CONFIG_BLK_DEV_IDECD 1
#define CONFIG_BLK_DEV_IDETAPE_MODULE 1
#define CONFIG_BLK_DEV_IDEFLOPPY 1
#define CONFIG_BLK_DEV_IDESCSI_MODULE 1
#undef CONFIG_IDE_TASK_IOCTL

/*
 * IDE chipset support/bugfixes
 */
#define CONFIG_IDE_GENERIC 1
#undef CONFIG_BLK_DEV_CMD640
#define CONFIG_BLK_DEV_IDEPNP 1
#define CONFIG_BLK_DEV_IDEPCI 1
#define CONFIG_IDEPCI_SHARE_IRQ 1
#undef CONFIG_BLK_DEV_OFFBOARD
#define CONFIG_BLK_DEV_GENERIC 1
#undef CONFIG_BLK_DEV_OPTI621
#define CONFIG_BLK_DEV_RZ1000 1
#define CONFIG_BLK_DEV_IDEDMA_PCI 1
#undef CONFIG_BLK_DEV_IDEDMA_FORCED
#define CONFIG_IDEDMA_PCI_AUTO 1
#undef CONFIG_IDEDMA_ONLYDISK
#define CONFIG_BLK_DEV_AEC62XX 1
#define CONFIG_BLK_DEV_ALI15X3 1
#undef CONFIG_WDC_ALI15X3
#define CONFIG_BLK_DEV_AMD74XX 1
#define CONFIG_BLK_DEV_ATIIXP 1
#define CONFIG_BLK_DEV_CMD64X 1
#define CONFIG_BLK_DEV_TRIFLEX 1
#define CONFIG_BLK_DEV_CY82C693 1
#define CONFIG_BLK_DEV_CS5520 1
#define CONFIG_BLK_DEV_CS5530 1
#define CONFIG_BLK_DEV_CS5535 1
#define CONFIG_BLK_DEV_HPT34X 1
#undef CONFIG_HPT34X_AUTODMA
#define CONFIG_BLK_DEV_HPT366 1
#undef CONFIG_BLK_DEV_SC1200
#define CONFIG_BLK_DEV_PIIX 1
#define CONFIG_BLK_DEV_IT821X 1
#undef CONFIG_BLK_DEV_NS87415
#define CONFIG_BLK_DEV_PDC202XX_OLD 1
#define CONFIG_PDC202XX_BURST 1
#define CONFIG_BLK_DEV_PDC202XX_NEW 1
#define CONFIG_BLK_DEV_SVWKS 1
#define CONFIG_BLK_DEV_SIIMAGE 1
#define CONFIG_BLK_DEV_SIS5513 1
#define CONFIG_BLK_DEV_SLC90E66 1
#define CONFIG_BLK_DEV_TRM290_MODULE 1
#define CONFIG_BLK_DEV_VIA82CXXX 1
#undef CONFIG_IDE_ARM
#define CONFIG_IDE_CHIPSETS 1

/*
 * Note: most of these also require special kernel boot parameters
 */
#define CONFIG_BLK_DEV_4DRIVES 1
#define CONFIG_BLK_DEV_ALI14XX_MODULE 1
#define CONFIG_BLK_DEV_DTC2278_MODULE 1
#define CONFIG_BLK_DEV_HT6560B_MODULE 1
#define CONFIG_BLK_DEV_QD65XX_MODULE 1
#define CONFIG_BLK_DEV_UMC8672_MODULE 1
#define CONFIG_BLK_DEV_IDEDMA 1
#undef CONFIG_IDEDMA_IVB
#define CONFIG_IDEDMA_AUTO 1
#undef CONFIG_BLK_DEV_HD

/*
 * SCSI device support
 */
#define CONFIG_RAID_ATTRS_MODULE 1
#define CONFIG_SCSI 1
#define CONFIG_SCSI_PROC_FS 1

/*
 * SCSI support type (disk, tape, CD-ROM)
 */
#define CONFIG_BLK_DEV_SD 1
#define CONFIG_CHR_DEV_ST_MODULE 1
#define CONFIG_CHR_DEV_OSST_MODULE 1
#define CONFIG_BLK_DEV_SR 1
#define CONFIG_BLK_DEV_SR_VENDOR 1
#define CONFIG_CHR_DEV_SG_MODULE 1
#define CONFIG_CHR_DEV_SCH_MODULE 1

/*
 * Some SCSI devices (e.g. CD jukebox) support multiple LUNs
 */
#undef CONFIG_SCSI_MULTI_LUN
#undef CONFIG_SCSI_CONSTANTS
#undef CONFIG_SCSI_LOGGING

/*
 * SCSI Transport Attributes
 */
#define CONFIG_SCSI_SPI_ATTRS_MODULE 1
#define CONFIG_SCSI_FC_ATTRS_MODULE 1
#define CONFIG_SCSI_ISCSI_ATTRS_MODULE 1
#define CONFIG_SCSI_SAS_ATTRS_MODULE 1

/*
 * SCSI low-level drivers
 */
#define CONFIG_ISCSI_TCP_MODULE 1
#define CONFIG_BLK_DEV_3W_XXXX_RAID_MODULE 1
#define CONFIG_SCSI_3W_9XXX_MODULE 1
#define CONFIG_SCSI_7000FASST_MODULE 1
#define CONFIG_SCSI_ACARD_MODULE 1
#define CONFIG_SCSI_AHA152X_MODULE 1
#define CONFIG_SCSI_AHA1542_MODULE 1
#define CONFIG_SCSI_AACRAID_MODULE 1
#define CONFIG_SCSI_AIC7XXX_MODULE 1
#define CONFIG_AIC7XXX_CMDS_PER_DEVICE 4
#define CONFIG_AIC7XXX_RESET_DELAY_MS 15000
#undef CONFIG_AIC7XXX_DEBUG_ENABLE
#define CONFIG_AIC7XXX_DEBUG_MASK 0
#undef CONFIG_AIC7XXX_REG_PRETTY_PRINT
#define CONFIG_SCSI_AIC7XXX_OLD_MODULE 1
#define CONFIG_SCSI_AIC79XX_MODULE 1
#define CONFIG_AIC79XX_CMDS_PER_DEVICE 4
#define CONFIG_AIC79XX_RESET_DELAY_MS 15000
#undef CONFIG_AIC79XX_ENABLE_RD_STRM
#undef CONFIG_AIC79XX_DEBUG_ENABLE
#define CONFIG_AIC79XX_DEBUG_MASK 0
#undef CONFIG_AIC79XX_REG_PRETTY_PRINT
#define CONFIG_SCSI_DPT_I2O_MODULE 1
#define CONFIG_SCSI_ADVANSYS_MODULE 1
#define CONFIG_SCSI_IN2000_MODULE 1
#define CONFIG_MEGARAID_NEWGEN 1
#define CONFIG_MEGARAID_MM_MODULE 1
#define CONFIG_MEGARAID_MAILBOX_MODULE 1
#define CONFIG_MEGARAID_LEGACY_MODULE 1
#define CONFIG_MEGARAID_SAS_MODULE 1
#define CONFIG_SCSI_SATA 1
#define CONFIG_SCSI_SATA_AHCI 1
#define CONFIG_SCSI_SATA_SVW 1
#define CONFIG_SCSI_ATA_PIIX 1
#define CONFIG_SCSI_SATA_MV_MODULE 1
#define CONFIG_SCSI_SATA_NV 1
#define CONFIG_SCSI_PDC_ADMA 1
#define CONFIG_SCSI_SATA_QSTOR 1
#define CONFIG_SCSI_SATA_PROMISE 1
#define CONFIG_SCSI_SATA_SX4 1
#define CONFIG_SCSI_SATA_SIL 1
#define CONFIG_SCSI_SATA_SIL24 1
#define CONFIG_SCSI_SATA_SIS 1
#define CONFIG_SCSI_SATA_ULI 1
#define CONFIG_SCSI_SATA_VIA 1
#define CONFIG_SCSI_SATA_VITESSE 1
#define CONFIG_SCSI_SATA_INTEL_COMBINED 1
#define CONFIG_SCSI_BUSLOGIC_MODULE 1
#undef CONFIG_SCSI_OMIT_FLASHPOINT
#define CONFIG_SCSI_DMX3191D_MODULE 1
#define CONFIG_SCSI_DTC3280_MODULE 1
#define CONFIG_SCSI_EATA_MODULE 1
#undef CONFIG_SCSI_EATA_TAGGED_QUEUE
#undef CONFIG_SCSI_EATA_LINKED_COMMANDS
#define CONFIG_SCSI_EATA_MAX_TAGS 16
#define CONFIG_SCSI_FUTURE_DOMAIN_MODULE 1
#define CONFIG_SCSI_GDTH_MODULE 1
#define CONFIG_SCSI_GENERIC_NCR5380_MODULE 1
#define CONFIG_SCSI_GENERIC_NCR5380_MMIO_MODULE 1
#define CONFIG_SCSI_GENERIC_NCR53C400 1
#define CONFIG_SCSI_IPS_MODULE 1
#define CONFIG_SCSI_INITIO_MODULE 1
#define CONFIG_SCSI_INIA100_MODULE 1
#define CONFIG_SCSI_PPA_MODULE 1
#define CONFIG_SCSI_IMM_MODULE 1
#undef CONFIG_SCSI_IZIP_EPP16
#undef CONFIG_SCSI_IZIP_SLOW_CTR
#define CONFIG_SCSI_NCR53C406A_MODULE 1
#define CONFIG_SCSI_SYM53C8XX_2_MODULE 1
#define CONFIG_SCSI_SYM53C8XX_DMA_ADDRESSING_MODE 1
#define CONFIG_SCSI_SYM53C8XX_DEFAULT_TAGS 16
#define CONFIG_SCSI_SYM53C8XX_MAX_TAGS 64
#define CONFIG_SCSI_SYM53C8XX_MMIO 1
#define CONFIG_SCSI_IPR_MODULE 1
#undef CONFIG_SCSI_IPR_TRACE
#undef CONFIG_SCSI_IPR_DUMP
#define CONFIG_SCSI_PAS16_MODULE 1
#define CONFIG_SCSI_PSI240I_MODULE 1
#define CONFIG_SCSI_QLOGIC_FAS_MODULE 1
#define CONFIG_SCSI_QLOGIC_1280_MODULE 1
#define CONFIG_SCSI_QLA_FC_MODULE 1
#undef CONFIG_SCSI_QLA2XXX_EMBEDDED_FIRMWARE
#define CONFIG_SCSI_LPFC_MODULE 1
#define CONFIG_SCSI_SYM53C416_MODULE 1
#define CONFIG_SCSI_DC395x_MODULE 1
#define CONFIG_SCSI_DC390T_MODULE 1
#define CONFIG_SCSI_T128_MODULE 1
#define CONFIG_SCSI_U14_34F_MODULE 1
#undef CONFIG_SCSI_U14_34F_TAGGED_QUEUE
#undef CONFIG_SCSI_U14_34F_LINKED_COMMANDS
#define CONFIG_SCSI_U14_34F_MAX_TAGS 8
#define CONFIG_SCSI_ULTRASTOR_MODULE 1
#define CONFIG_SCSI_NSP32_MODULE 1
#define CONFIG_SCSI_DEBUG_MODULE 1

/*
 * PCMCIA SCSI adapter support
 */
#define CONFIG_PCMCIA_AHA152X_MODULE 1
#define CONFIG_PCMCIA_FDOMAIN_MODULE 1
#define CONFIG_PCMCIA_NINJA_SCSI_MODULE 1
#define CONFIG_PCMCIA_QLOGIC_MODULE 1
#define CONFIG_PCMCIA_SYM53C500_MODULE 1

/*
 * Old CD-ROM drivers (not SCSI, not IDE)
 */
#define CONFIG_CD_NO_IDESCSI 1
#define CONFIG_AZTCD_MODULE 1
#define CONFIG_GSCD_MODULE 1
#define CONFIG_SBPCD_MODULE 1
#define CONFIG_MCDX_MODULE 1
#define CONFIG_OPTCD_MODULE 1
#define CONFIG_CM206_MODULE 1
#define CONFIG_SJCD_MODULE 1
#define CONFIG_ISP16_CDI_MODULE 1
#define CONFIG_CDU31A_MODULE 1
#define CONFIG_CDU535_MODULE 1

/*
 * Multi-device support (RAID and LVM)
 */
#define CONFIG_MD 1
#define CONFIG_BLK_DEV_MD 1
#define CONFIG_MD_LINEAR 1
#define CONFIG_MD_RAID0 1
#define CONFIG_MD_RAID1 1
#define CONFIG_MD_RAID10_MODULE 1
#define CONFIG_MD_RAID5 1
#define CONFIG_MD_RAID5_RESHAPE 1
#define CONFIG_MD_RAID6 1
#define CONFIG_MD_MULTIPATH_MODULE 1
#define CONFIG_MD_FAULTY_MODULE 1
#define CONFIG_BLK_DEV_DM_MODULE 1
#define CONFIG_DM_CRYPT_MODULE 1
#define CONFIG_DM_SNAPSHOT_MODULE 1
#define CONFIG_DM_MIRROR_MODULE 1
#define CONFIG_DM_ZERO_MODULE 1
#define CONFIG_DM_MULTIPATH_MODULE 1
#define CONFIG_DM_MULTIPATH_EMC_MODULE 1

/*
 * Fusion MPT device support
 */
#define CONFIG_FUSION 1
#define CONFIG_FUSION_SPI_MODULE 1
#define CONFIG_FUSION_FC_MODULE 1
#define CONFIG_FUSION_SAS_MODULE 1
#define CONFIG_FUSION_MAX_SGE 128
#define CONFIG_FUSION_CTL_MODULE 1
#define CONFIG_FUSION_LAN_MODULE 1

/*
 * IEEE 1394 (FireWire) support
 */
#define CONFIG_IEEE1394_MODULE 1

/*
 * Subsystem Options
 */
#undef CONFIG_IEEE1394_VERBOSEDEBUG
#undef CONFIG_IEEE1394_OUI_DB
#define CONFIG_IEEE1394_EXTRA_CONFIG_ROMS 1
#define CONFIG_IEEE1394_CONFIG_ROM_IP1394 1
#undef CONFIG_IEEE1394_EXPORT_FULL_API

/*
 * Device Drivers
 */
#define CONFIG_IEEE1394_PCILYNX_MODULE 1
#define CONFIG_IEEE1394_OHCI1394_MODULE 1

/*
 * Protocol Drivers
 */
#define CONFIG_IEEE1394_VIDEO1394_MODULE 1
#define CONFIG_IEEE1394_SBP2_MODULE 1
#undef CONFIG_IEEE1394_SBP2_PHYS_DMA
#define CONFIG_IEEE1394_ETH1394_MODULE 1
#define CONFIG_IEEE1394_DV1394_MODULE 1
#define CONFIG_IEEE1394_RAWIO_MODULE 1

/*
 * I2O device support
 */
#define CONFIG_I2O_MODULE 1
#define CONFIG_I2O_LCT_NOTIFY_ON_CHANGES 1
#define CONFIG_I2O_EXT_ADAPTEC 1
#define CONFIG_I2O_CONFIG_MODULE 1
#define CONFIG_I2O_CONFIG_OLD_IOCTL 1
#define CONFIG_I2O_BUS_MODULE 1
#define CONFIG_I2O_BLOCK_MODULE 1
#define CONFIG_I2O_SCSI_MODULE 1
#define CONFIG_I2O_PROC_MODULE 1

/*
 * Network device support
 */
#define CONFIG_NETDEVICES 1
#define CONFIG_DUMMY_MODULE 1
#define CONFIG_BONDING_MODULE 1
#define CONFIG_EQUALIZER_MODULE 1
#define CONFIG_TUN_MODULE 1
#define CONFIG_NET_SB1000_MODULE 1

/*
 * ARCnet devices
 */
#define CONFIG_ARCNET_MODULE 1
#define CONFIG_ARCNET_1201_MODULE 1
#define CONFIG_ARCNET_1051_MODULE 1
#define CONFIG_ARCNET_RAW_MODULE 1
#define CONFIG_ARCNET_CAP_MODULE 1
#define CONFIG_ARCNET_COM90xx_MODULE 1
#define CONFIG_ARCNET_COM90xxIO_MODULE 1
#define CONFIG_ARCNET_RIM_I_MODULE 1
#define CONFIG_ARCNET_COM20020_MODULE 1
#define CONFIG_ARCNET_COM20020_ISA_MODULE 1
#define CONFIG_ARCNET_COM20020_PCI_MODULE 1

/*
 * PHY device support
 */
#define CONFIG_PHYLIB_MODULE 1

/*
 * MII PHY device drivers
 */
#define CONFIG_MARVELL_PHY_MODULE 1
#define CONFIG_DAVICOM_PHY_MODULE 1
#define CONFIG_QSEMI_PHY_MODULE 1
#define CONFIG_LXT_PHY_MODULE 1
#define CONFIG_CICADA_PHY_MODULE 1

/*
 * Ethernet (10 or 100Mbit)
 */
#define CONFIG_NET_ETHERNET 1
#define CONFIG_MII_MODULE 1
#define CONFIG_HAPPYMEAL_MODULE 1
#define CONFIG_SUNGEM_MODULE 1
#define CONFIG_CASSINI_MODULE 1
#define CONFIG_NET_VENDOR_3COM 1
#define CONFIG_EL1_MODULE 1
#define CONFIG_EL2_MODULE 1
#define CONFIG_ELPLUS_MODULE 1
#define CONFIG_EL16_MODULE 1
#define CONFIG_EL3_MODULE 1
#define CONFIG_3C515_MODULE 1
#define CONFIG_VORTEX_MODULE 1
#define CONFIG_TYPHOON_MODULE 1
#define CONFIG_LANCE_MODULE 1
#define CONFIG_NET_VENDOR_SMC 1
#define CONFIG_WD80x3_MODULE 1
#define CONFIG_ULTRA_MODULE 1
#define CONFIG_SMC9194_MODULE 1
#define CONFIG_NET_VENDOR_RACAL 1
#define CONFIG_NI5010_MODULE 1
#define CONFIG_NI52_MODULE 1
#define CONFIG_NI65_MODULE 1

/*
 * Tulip family network device support
 */
#define CONFIG_NET_TULIP 1
#define CONFIG_DE2104X_MODULE 1
#define CONFIG_TULIP_MODULE 1
#undef CONFIG_TULIP_MWI
#define CONFIG_TULIP_MMIO 1
#undef CONFIG_TULIP_NAPI
#define CONFIG_DE4X5_MODULE 1
#define CONFIG_WINBOND_840_MODULE 1
#define CONFIG_DM9102_MODULE 1
#define CONFIG_ULI526X_MODULE 1
#define CONFIG_PCMCIA_XIRCOM_MODULE 1
#define CONFIG_PCMCIA_XIRTULIP_MODULE 1
#define CONFIG_AT1700_MODULE 1
#define CONFIG_DEPCA_MODULE 1
#define CONFIG_HP100_MODULE 1
#define CONFIG_NET_ISA 1
#define CONFIG_E2100_MODULE 1
#define CONFIG_EWRK3_MODULE 1
#define CONFIG_EEXPRESS_MODULE 1
#define CONFIG_EEXPRESS_PRO_MODULE 1
#define CONFIG_HPLAN_PLUS_MODULE 1
#define CONFIG_HPLAN_MODULE 1
#define CONFIG_LP486E_MODULE 1
#define CONFIG_ETH16I_MODULE 1
#define CONFIG_NE2000_MODULE 1
#define CONFIG_ZNET_MODULE 1
#define CONFIG_SEEQ8005_MODULE 1
#define CONFIG_NET_PCI 1
#define CONFIG_PCNET32_MODULE 1
#define CONFIG_AMD8111_ETH_MODULE 1
#undef CONFIG_AMD8111E_NAPI
#define CONFIG_ADAPTEC_STARFIRE_MODULE 1
#define CONFIG_ADAPTEC_STARFIRE_NAPI 1
#define CONFIG_AC3200_MODULE 1
#define CONFIG_APRICOT_MODULE 1
#define CONFIG_B44_MODULE 1
#define CONFIG_FORCEDETH_MODULE 1
#define CONFIG_CS89x0_MODULE 1
#define CONFIG_DGRS_MODULE 1
#define CONFIG_EEPRO100_MODULE 1
#define CONFIG_E100_MODULE 1
#define CONFIG_FEALNX_MODULE 1
#define CONFIG_NATSEMI_MODULE 1
#define CONFIG_NE2K_PCI_MODULE 1
#define CONFIG_8139CP_MODULE 1
#define CONFIG_8139TOO_MODULE 1
#define CONFIG_8139TOO_PIO 1
#undef CONFIG_8139TOO_TUNE_TWISTER
#define CONFIG_8139TOO_8129 1
#undef CONFIG_8139_OLD_RX_RESET
#define CONFIG_SIS900_MODULE 1
#define CONFIG_EPIC100_MODULE 1
#define CONFIG_SUNDANCE_MODULE 1
#undef CONFIG_SUNDANCE_MMIO
#define CONFIG_TLAN_MODULE 1
#define CONFIG_VIA_RHINE_MODULE 1
#define CONFIG_VIA_RHINE_MMIO 1
#define CONFIG_NET_POCKET 1
#define CONFIG_ATP_MODULE 1
#define CONFIG_DE600_MODULE 1
#define CONFIG_DE620_MODULE 1

/*
 * Ethernet (1000 Mbit)
 */
#define CONFIG_ACENIC_MODULE 1
#undef CONFIG_ACENIC_OMIT_TIGON_I
#define CONFIG_DL2K_MODULE 1
#define CONFIG_E1000_MODULE 1
#define CONFIG_E1000_NAPI 1
#undef CONFIG_E1000_DISABLE_PACKET_SPLIT
#define CONFIG_NS83820_MODULE 1
#define CONFIG_HAMACHI_MODULE 1
#define CONFIG_YELLOWFIN_MODULE 1
#define CONFIG_R8169_MODULE 1
#undef CONFIG_R8169_NAPI
#define CONFIG_R8169_VLAN 1
#define CONFIG_SIS190_MODULE 1
#define CONFIG_SKGE_MODULE 1
#define CONFIG_SKY2_MODULE 1
#define CONFIG_SK98LIN_MODULE 1
#define CONFIG_VIA_VELOCITY_MODULE 1
#define CONFIG_TIGON3_MODULE 1
#define CONFIG_BNX2_MODULE 1

/*
 * Ethernet (10000 Mbit)
 */
#define CONFIG_CHELSIO_T1_MODULE 1
#define CONFIG_IXGB_MODULE 1
#define CONFIG_IXGB_NAPI 1
#define CONFIG_S2IO_MODULE 1
#undef CONFIG_S2IO_NAPI

/*
 * Token Ring devices
 */
#define CONFIG_TR 1
#define CONFIG_IBMTR_MODULE 1
#define CONFIG_IBMOL_MODULE 1
#define CONFIG_IBMLS_MODULE 1
#define CONFIG_3C359_MODULE 1
#define CONFIG_TMS380TR_MODULE 1
#define CONFIG_TMSPCI_MODULE 1
#define CONFIG_SKISA_MODULE 1
#define CONFIG_PROTEON_MODULE 1
#define CONFIG_ABYSS_MODULE 1
#define CONFIG_SMCTR_MODULE 1

/*
 * Wireless LAN (non-hamradio)
 */
#define CONFIG_NET_RADIO 1
#define CONFIG_NET_WIRELESS_RTNETLINK 1

/*
 * Obsolete Wireless cards support (pre-802.11)
 */
#define CONFIG_STRIP_MODULE 1
#define CONFIG_ARLAN_MODULE 1
#define CONFIG_WAVELAN_MODULE 1
#define CONFIG_PCMCIA_WAVELAN_MODULE 1
#define CONFIG_PCMCIA_NETWAVE_MODULE 1

/*
 * Wireless 802.11 Frequency Hopping cards support
 */
#define CONFIG_PCMCIA_RAYCS_MODULE 1

/*
 * Wireless 802.11b ISA/PCI cards support
 */
#define CONFIG_IPW2100_MODULE 1
#define CONFIG_IPW2100_MONITOR 1
#undef CONFIG_IPW2100_DEBUG
#define CONFIG_IPW2200_MODULE 1
#define CONFIG_IPW2200_MONITOR 1
#define CONFIG_IPW_QOS 1
#undef CONFIG_IPW2200_DEBUG
#define CONFIG_AIRO_MODULE 1
#define CONFIG_HERMES_MODULE 1
#define CONFIG_PLX_HERMES_MODULE 1
#define CONFIG_TMD_HERMES_MODULE 1
#define CONFIG_NORTEL_HERMES_MODULE 1
#define CONFIG_PCI_HERMES_MODULE 1
#define CONFIG_ATMEL_MODULE 1
#define CONFIG_PCI_ATMEL_MODULE 1

/*
 * Wireless 802.11b Pcmcia/Cardbus cards support
 */
#define CONFIG_PCMCIA_HERMES_MODULE 1
#define CONFIG_PCMCIA_SPECTRUM_MODULE 1
#define CONFIG_AIRO_CS_MODULE 1
#define CONFIG_PCMCIA_ATMEL_MODULE 1
#define CONFIG_PCMCIA_WL3501_MODULE 1

/*
 * Prism GT/Duette 802.11(a/b/g) PCI/Cardbus support
 */
#define CONFIG_PRISM54_MODULE 1
#define CONFIG_HOSTAP_MODULE 1
#define CONFIG_HOSTAP_FIRMWARE 1
#define CONFIG_HOSTAP_FIRMWARE_NVRAM 1
#define CONFIG_HOSTAP_PLX_MODULE 1
#define CONFIG_HOSTAP_PCI_MODULE 1
#define CONFIG_HOSTAP_CS_MODULE 1
#define CONFIG_BCM43XX_MODULE 1
#define CONFIG_BCM43XX_DEBUG 1
#define CONFIG_BCM43XX_DMA 1
#define CONFIG_BCM43XX_PIO 1
#define CONFIG_BCM43XX_DMA_AND_PIO_MODE 1
#undef CONFIG_BCM43XX_DMA_MODE
#undef CONFIG_BCM43XX_PIO_MODE
#define CONFIG_NET_WIRELESS 1

/*
 * PCMCIA network device support
 */
#define CONFIG_NET_PCMCIA 1
#define CONFIG_PCMCIA_3C589_MODULE 1
#define CONFIG_PCMCIA_3C574_MODULE 1
#define CONFIG_PCMCIA_FMVJ18X_MODULE 1
#define CONFIG_PCMCIA_PCNET_MODULE 1
#define CONFIG_PCMCIA_NMCLAN_MODULE 1
#define CONFIG_PCMCIA_SMC91C92_MODULE 1
#define CONFIG_PCMCIA_XIRC2PS_MODULE 1
#define CONFIG_PCMCIA_AXNET_MODULE 1
#define CONFIG_ARCNET_COM20020_CS_MODULE 1
#define CONFIG_PCMCIA_IBMTR_MODULE 1

/*
 * Wan interfaces
 */
#define CONFIG_WAN 1
#define CONFIG_HOSTESS_SV11_MODULE 1
#define CONFIG_COSA_MODULE 1
#define CONFIG_DSCC4_MODULE 1
#undef CONFIG_DSCC4_PCISYNC
#undef CONFIG_DSCC4_PCI_RST
#define CONFIG_LANMEDIA_MODULE 1
#define CONFIG_SEALEVEL_4021_MODULE 1
#define CONFIG_SYNCLINK_SYNCPPP_MODULE 1
#define CONFIG_HDLC_MODULE 1
#define CONFIG_HDLC_RAW 1
#define CONFIG_HDLC_RAW_ETH 1
#define CONFIG_HDLC_CISCO 1
#define CONFIG_HDLC_FR 1
#define CONFIG_HDLC_PPP 1

/*
 * X.25/LAPB support is disabled
 */
#define CONFIG_PCI200SYN_MODULE 1
#define CONFIG_WANXL_MODULE 1
#define CONFIG_PC300_MODULE 1
#undef CONFIG_PC300_MLPPP
#define CONFIG_N2_MODULE 1
#define CONFIG_C101_MODULE 1
#define CONFIG_FARSYNC_MODULE 1
#define CONFIG_DLCI_MODULE 1
#define CONFIG_DLCI_COUNT 24
#define CONFIG_DLCI_MAX 8
#define CONFIG_SDLA_MODULE 1
#define CONFIG_WAN_ROUTER_DRIVERS 1
#define CONFIG_CYCLADES_SYNC_MODULE 1
#define CONFIG_CYCLOMX_X25 1
#define CONFIG_SBNI_MODULE 1
#undef CONFIG_SBNI_MULTILINE

/*
 * ATM drivers
 */
#define CONFIG_ATM_DUMMY_MODULE 1
#define CONFIG_ATM_TCP_MODULE 1
#define CONFIG_ATM_LANAI_MODULE 1
#define CONFIG_ATM_ENI_MODULE 1
#undef CONFIG_ATM_ENI_DEBUG
#undef CONFIG_ATM_ENI_TUNE_BURST
#define CONFIG_ATM_FIRESTREAM_MODULE 1
#define CONFIG_ATM_ZATM_MODULE 1
#undef CONFIG_ATM_ZATM_DEBUG
#define CONFIG_ATM_NICSTAR_MODULE 1
#undef CONFIG_ATM_NICSTAR_USE_SUNI
#undef CONFIG_ATM_NICSTAR_USE_IDT77105
#define CONFIG_ATM_IDT77252_MODULE 1
#undef CONFIG_ATM_IDT77252_DEBUG
#undef CONFIG_ATM_IDT77252_RCV_ALL
#define CONFIG_ATM_IDT77252_USE_SUNI 1
#define CONFIG_ATM_AMBASSADOR_MODULE 1
#undef CONFIG_ATM_AMBASSADOR_DEBUG
#define CONFIG_ATM_HORIZON_MODULE 1
#undef CONFIG_ATM_HORIZON_DEBUG
#define CONFIG_ATM_IA_MODULE 1
#undef CONFIG_ATM_IA_DEBUG
#define CONFIG_ATM_FORE200E_MAYBE_MODULE 1
#undef CONFIG_ATM_FORE200E_PCA
#define CONFIG_ATM_HE_MODULE 1
#undef CONFIG_ATM_HE_USE_SUNI
#define CONFIG_FDDI 1
#define CONFIG_DEFXX_MODULE 1
#define CONFIG_SKFP_MODULE 1
#define CONFIG_HIPPI 1
#define CONFIG_ROADRUNNER_MODULE 1
#undef CONFIG_ROADRUNNER_LARGE_RINGS
#define CONFIG_PLIP_MODULE 1
#define CONFIG_PPP_MODULE 1
#define CONFIG_PPP_MULTILINK 1
#define CONFIG_PPP_FILTER 1
#define CONFIG_PPP_ASYNC_MODULE 1
#define CONFIG_PPP_SYNC_TTY_MODULE 1
#define CONFIG_PPP_DEFLATE_MODULE 1
#define CONFIG_PPP_BSDCOMP_MODULE 1
#define CONFIG_PPP_MPPE_MODULE 1
#define CONFIG_PPPOE_MODULE 1
#define CONFIG_PPPOATM_MODULE 1
#define CONFIG_SLIP_MODULE 1
#define CONFIG_SLIP_COMPRESSED 1
#define CONFIG_SLIP_SMART 1
#undef CONFIG_SLIP_MODE_SLIP6
#define CONFIG_NET_FC 1
#define CONFIG_SHAPER_MODULE 1
#define CONFIG_NETCONSOLE_MODULE 1
#define CONFIG_NETPOLL 1
#undef CONFIG_NETPOLL_RX
#undef CONFIG_NETPOLL_TRAP
#define CONFIG_NET_POLL_CONTROLLER 1

/*
 * ISDN subsystem
 */
#define CONFIG_ISDN_MODULE 1

/*
 * Old ISDN4Linux
 */
#define CONFIG_ISDN_I4L_MODULE 1
#define CONFIG_ISDN_PPP 1
#define CONFIG_ISDN_PPP_VJ 1
#define CONFIG_ISDN_MPP 1
#define CONFIG_IPPP_FILTER 1
#define CONFIG_ISDN_PPP_BSDCOMP_MODULE 1
#define CONFIG_ISDN_AUDIO 1
#define CONFIG_ISDN_TTY_FAX 1

/*
 * ISDN feature submodules
 */
#define CONFIG_ISDN_DRV_LOOP_MODULE 1
#define CONFIG_ISDN_DIVERSION_MODULE 1

/*
 * ISDN4Linux hardware drivers
 */

/*
 * Passive cards
 */
#define CONFIG_ISDN_DRV_HISAX_MODULE 1

/*
 * D-channel protocol features
 */
#define CONFIG_HISAX_EURO 1
#define CONFIG_DE_AOC 1
#define CONFIG_HISAX_NO_SENDCOMPLETE 1
#define CONFIG_HISAX_NO_LLC 1
#define CONFIG_HISAX_NO_KEYPAD 1
#define CONFIG_HISAX_1TR6 1
#define CONFIG_HISAX_NI1 1
#define CONFIG_HISAX_MAX_CARDS 8

/*
 * HiSax supported cards
 */
#define CONFIG_HISAX_16_0 1
#define CONFIG_HISAX_16_3 1
#define CONFIG_HISAX_TELESPCI 1
#define CONFIG_HISAX_S0BOX 1
#define CONFIG_HISAX_AVM_A1 1
#define CONFIG_HISAX_FRITZPCI 1
#define CONFIG_HISAX_AVM_A1_PCMCIA 1
#define CONFIG_HISAX_ELSA 1
#define CONFIG_HISAX_IX1MICROR2 1
#define CONFIG_HISAX_DIEHLDIVA 1
#define CONFIG_HISAX_ASUSCOM 1
#define CONFIG_HISAX_TELEINT 1
#define CONFIG_HISAX_HFCS 1
#define CONFIG_HISAX_SEDLBAUER 1
#define CONFIG_HISAX_SPORTSTER 1
#define CONFIG_HISAX_MIC 1
#define CONFIG_HISAX_NETJET 1
#define CONFIG_HISAX_NETJET_U 1
#define CONFIG_HISAX_NICCY 1
#define CONFIG_HISAX_ISURF 1
#define CONFIG_HISAX_HSTSAPHIR 1
#define CONFIG_HISAX_BKM_A4T 1
#define CONFIG_HISAX_SCT_QUADRO 1
#define CONFIG_HISAX_GAZEL 1
#define CONFIG_HISAX_HFC_PCI 1
#define CONFIG_HISAX_W6692 1
#define CONFIG_HISAX_HFC_SX 1
#define CONFIG_HISAX_ENTERNOW_PCI 1
#undef CONFIG_HISAX_DEBUG

/*
 * HiSax PCMCIA card service modules
 */
#define CONFIG_HISAX_SEDLBAUER_CS_MODULE 1
#define CONFIG_HISAX_ELSA_CS_MODULE 1
#define CONFIG_HISAX_AVM_A1_CS_MODULE 1
#define CONFIG_HISAX_TELES_CS_MODULE 1

/*
 * HiSax sub driver modules
 */
#define CONFIG_HISAX_ST5481_MODULE 1
#define CONFIG_HISAX_HFCUSB_MODULE 1
#define CONFIG_HISAX_HFC4S8S_MODULE 1
#define CONFIG_HISAX_FRITZ_PCIPNP_MODULE 1
#define CONFIG_HISAX_HDLC 1

/*
 * Active cards
 */
#define CONFIG_ISDN_DRV_ICN_MODULE 1
#define CONFIG_ISDN_DRV_PCBIT_MODULE 1
#define CONFIG_ISDN_DRV_SC_MODULE 1
#define CONFIG_ISDN_DRV_ACT2000_MODULE 1
#define CONFIG_HYSDN_MODULE 1
#define CONFIG_HYSDN_CAPI 1

/*
 * Siemens Gigaset
 */
#define CONFIG_ISDN_DRV_GIGASET_MODULE 1
#define CONFIG_GIGASET_BASE_MODULE 1
#define CONFIG_GIGASET_M105_MODULE 1
#undef CONFIG_GIGASET_DEBUG
#undef CONFIG_GIGASET_UNDOCREQ

/*
 * CAPI subsystem
 */
#define CONFIG_ISDN_CAPI_MODULE 1
#define CONFIG_ISDN_DRV_AVMB1_VERBOSE_REASON 1
#define CONFIG_ISDN_CAPI_MIDDLEWARE 1
#define CONFIG_ISDN_CAPI_CAPI20_MODULE 1
#define CONFIG_ISDN_CAPI_CAPIFS_BOOL 1
#define CONFIG_ISDN_CAPI_CAPIFS_MODULE 1
#define CONFIG_ISDN_CAPI_CAPIDRV_MODULE 1

/*
 * CAPI hardware drivers
 */

/*
 * Active AVM cards
 */
#define CONFIG_CAPI_AVM 1
#define CONFIG_ISDN_DRV_AVMB1_B1ISA_MODULE 1
#define CONFIG_ISDN_DRV_AVMB1_B1PCI_MODULE 1
#define CONFIG_ISDN_DRV_AVMB1_B1PCIV4 1
#define CONFIG_ISDN_DRV_AVMB1_T1ISA_MODULE 1
#define CONFIG_ISDN_DRV_AVMB1_B1PCMCIA_MODULE 1
#define CONFIG_ISDN_DRV_AVMB1_AVM_CS_MODULE 1
#define CONFIG_ISDN_DRV_AVMB1_T1PCI_MODULE 1
#define CONFIG_ISDN_DRV_AVMB1_C4_MODULE 1

/*
 * Active Eicon DIVA Server cards
 */
#define CONFIG_CAPI_EICON 1
#define CONFIG_ISDN_DIVAS_MODULE 1
#define CONFIG_ISDN_DIVAS_BRIPCI 1
#define CONFIG_ISDN_DIVAS_PRIPCI 1
#define CONFIG_ISDN_DIVAS_DIVACAPI_MODULE 1
#define CONFIG_ISDN_DIVAS_USERIDI_MODULE 1
#define CONFIG_ISDN_DIVAS_MAINT_MODULE 1

/*
 * Telephony Support
 */
#define CONFIG_PHONE_MODULE 1
#define CONFIG_PHONE_IXJ_MODULE 1
#define CONFIG_PHONE_IXJ_PCMCIA_MODULE 1

/*
 * Input device support
 */
#define CONFIG_INPUT 1

/*
 * Userland interfaces
 */
#define CONFIG_INPUT_MOUSEDEV 1
#define CONFIG_INPUT_MOUSEDEV_PSAUX 1
#define CONFIG_INPUT_MOUSEDEV_SCREEN_X 1024
#define CONFIG_INPUT_MOUSEDEV_SCREEN_Y 768
#define CONFIG_INPUT_JOYDEV_MODULE 1
#undef CONFIG_INPUT_TSDEV
#define CONFIG_INPUT_EVDEV_MODULE 1
#undef CONFIG_INPUT_EVBUG

/*
 * Input Device Drivers
 */
#define CONFIG_INPUT_KEYBOARD 1
#define CONFIG_KEYBOARD_ATKBD 1
#undef CONFIG_KEYBOARD_SUNKBD
#undef CONFIG_KEYBOARD_LKKBD
#undef CONFIG_KEYBOARD_XTKBD
#undef CONFIG_KEYBOARD_NEWTON
#define CONFIG_INPUT_MOUSE 1
#define CONFIG_MOUSE_PS2_MODULE 1
#define CONFIG_MOUSE_SERIAL_MODULE 1
#define CONFIG_MOUSE_INPORT_MODULE 1
#define CONFIG_MOUSE_ATIXL 1
#define CONFIG_MOUSE_LOGIBM_MODULE 1
#define CONFIG_MOUSE_PC110PAD_MODULE 1
#define CONFIG_MOUSE_VSXXXAA_MODULE 1
#define CONFIG_INPUT_JOYSTICK 1
#define CONFIG_JOYSTICK_ANALOG_MODULE 1
#define CONFIG_JOYSTICK_A3D_MODULE 1
#define CONFIG_JOYSTICK_ADI_MODULE 1
#define CONFIG_JOYSTICK_COBRA_MODULE 1
#define CONFIG_JOYSTICK_GF2K_MODULE 1
#define CONFIG_JOYSTICK_GRIP_MODULE 1
#define CONFIG_JOYSTICK_GRIP_MP_MODULE 1
#define CONFIG_JOYSTICK_GUILLEMOT_MODULE 1
#define CONFIG_JOYSTICK_INTERACT_MODULE 1
#define CONFIG_JOYSTICK_SIDEWINDER_MODULE 1
#define CONFIG_JOYSTICK_TMDC_MODULE 1
#define CONFIG_JOYSTICK_IFORCE_MODULE 1
#define CONFIG_JOYSTICK_IFORCE_USB 1
#define CONFIG_JOYSTICK_IFORCE_232 1
#define CONFIG_JOYSTICK_WARRIOR_MODULE 1
#define CONFIG_JOYSTICK_MAGELLAN_MODULE 1
#define CONFIG_JOYSTICK_SPACEORB_MODULE 1
#define CONFIG_JOYSTICK_SPACEBALL_MODULE 1
#define CONFIG_JOYSTICK_STINGER_MODULE 1
#define CONFIG_JOYSTICK_TWIDJOY_MODULE 1
#define CONFIG_JOYSTICK_DB9_MODULE 1
#define CONFIG_JOYSTICK_GAMECON_MODULE 1
#define CONFIG_JOYSTICK_TURBOGRAFX_MODULE 1
#define CONFIG_JOYSTICK_JOYDUMP_MODULE 1
#define CONFIG_INPUT_TOUCHSCREEN 1
#define CONFIG_TOUCHSCREEN_GUNZE_MODULE 1
#define CONFIG_TOUCHSCREEN_ELO_MODULE 1
#define CONFIG_TOUCHSCREEN_MTOUCH_MODULE 1
#define CONFIG_TOUCHSCREEN_MK712_MODULE 1
#define CONFIG_INPUT_MISC 1
#define CONFIG_INPUT_PCSPKR_MODULE 1
#define CONFIG_INPUT_WISTRON_BTNS_MODULE 1
#define CONFIG_INPUT_UINPUT_MODULE 1

/*
 * Hardware I/O ports
 */
#define CONFIG_SERIO 1
#define CONFIG_SERIO_I8042 1
#define CONFIG_SERIO_SERPORT_MODULE 1
#define CONFIG_SERIO_CT82C710_MODULE 1
#define CONFIG_SERIO_PARKBD_MODULE 1
#define CONFIG_SERIO_PCIPS2_MODULE 1
#define CONFIG_SERIO_LIBPS2 1
#define CONFIG_SERIO_RAW_MODULE 1
#define CONFIG_GAMEPORT_MODULE 1
#define CONFIG_GAMEPORT_NS558_MODULE 1
#define CONFIG_GAMEPORT_L4_MODULE 1
#define CONFIG_GAMEPORT_EMU10K1_MODULE 1
#define CONFIG_GAMEPORT_FM801_MODULE 1

/*
 * Character devices
 */
#define CONFIG_VT 1
#define CONFIG_VT_CONSOLE 1
#define CONFIG_HW_CONSOLE 1
#define CONFIG_SERIAL_NONSTANDARD 1
#define CONFIG_COMPUTONE_MODULE 1
#define CONFIG_ROCKETPORT_MODULE 1
#define CONFIG_CYCLADES_MODULE 1
#undef CONFIG_CYZ_INTR
#define CONFIG_DIGIEPCA_MODULE 1
#define CONFIG_ESPSERIAL_MODULE 1
#define CONFIG_MOXA_INTELLIO_MODULE 1
#define CONFIG_MOXA_SMARTIO_MODULE 1
#define CONFIG_ISI_MODULE 1
#define CONFIG_SYNCLINK_MODULE 1
#define CONFIG_SYNCLINKMP_MODULE 1
#define CONFIG_SYNCLINK_GT_MODULE 1
#define CONFIG_N_HDLC_MODULE 1
#define CONFIG_RISCOM8_MODULE 1
#define CONFIG_SPECIALIX_MODULE 1
#undef CONFIG_SPECIALIX_RTSCTS
#define CONFIG_SX_MODULE 1
#define CONFIG_RIO_MODULE 1
#undef CONFIG_RIO_OLDPCI
#define CONFIG_STALDRV 1
#define CONFIG_STALLION_MODULE 1
#define CONFIG_ISTALLION_MODULE 1

/*
 * Serial drivers
 */
#define CONFIG_SERIAL_8250 1
#define CONFIG_SERIAL_8250_CONSOLE 1
#define CONFIG_SERIAL_8250_PCI 1
#define CONFIG_SERIAL_8250_PNP 1
#define CONFIG_SERIAL_8250_CS_MODULE 1
#define CONFIG_SERIAL_8250_NR_UARTS 4
#define CONFIG_SERIAL_8250_RUNTIME_UARTS 4
#define CONFIG_SERIAL_8250_EXTENDED 1
#define CONFIG_SERIAL_8250_MANY_PORTS 1
#define CONFIG_SERIAL_8250_SHARE_IRQ 1
#define CONFIG_SERIAL_8250_DETECT_IRQ 1
#define CONFIG_SERIAL_8250_RSA 1
#define CONFIG_SERIAL_8250_FOURPORT_MODULE 1
#define CONFIG_SERIAL_8250_ACCENT_MODULE 1
#define CONFIG_SERIAL_8250_BOCA_MODULE 1
#define CONFIG_SERIAL_8250_HUB6_MODULE 1

/*
 * Non-8250 serial port support
 */
#define CONFIG_SERIAL_CORE 1
#define CONFIG_SERIAL_CORE_CONSOLE 1
#define CONFIG_SERIAL_JSM_MODULE 1
#define CONFIG_UNIX98_PTYS 1
#define CONFIG_LEGACY_PTYS 1
#define CONFIG_LEGACY_PTY_COUNT 256
#define CONFIG_PRINTER_MODULE 1
#define CONFIG_LP_CONSOLE 1
#define CONFIG_PPDEV_MODULE 1
#define CONFIG_TIPAR_MODULE 1

/*
 * IPMI
 */
#define CONFIG_IPMI_HANDLER_MODULE 1
#undef CONFIG_IPMI_PANIC_EVENT
#define CONFIG_IPMI_DEVICE_INTERFACE_MODULE 1
#define CONFIG_IPMI_SI_MODULE 1
#define CONFIG_IPMI_WATCHDOG_MODULE 1
#define CONFIG_IPMI_POWEROFF_MODULE 1

/*
 * Watchdog Cards
 */
#define CONFIG_WATCHDOG 1
#undef CONFIG_WATCHDOG_NOWAYOUT

/*
 * Watchdog Device Drivers
 */
#define CONFIG_SOFT_WATCHDOG_MODULE 1
#define CONFIG_ACQUIRE_WDT_MODULE 1
#define CONFIG_ADVANTECH_WDT_MODULE 1
#define CONFIG_ALIM1535_WDT_MODULE 1
#define CONFIG_ALIM7101_WDT_MODULE 1
#define CONFIG_SC520_WDT_MODULE 1
#define CONFIG_EUROTECH_WDT_MODULE 1
#define CONFIG_IB700_WDT_MODULE 1
#define CONFIG_IBMASR_MODULE 1
#define CONFIG_WAFER_WDT_MODULE 1
#define CONFIG_I6300ESB_WDT_MODULE 1
#define CONFIG_I8XX_TCO_MODULE 1
#define CONFIG_SC1200_WDT_MODULE 1
#define CONFIG_SCx200_WDT_MODULE 1
#define CONFIG_60XX_WDT_MODULE 1
#define CONFIG_SBC8360_WDT_MODULE 1
#define CONFIG_CPU5_WDT_MODULE 1
#define CONFIG_W83627HF_WDT_MODULE 1
#define CONFIG_W83877F_WDT_MODULE 1
#define CONFIG_W83977F_WDT_MODULE 1
#define CONFIG_MACHZ_WDT_MODULE 1
#define CONFIG_SBC_EPX_C3_WATCHDOG_MODULE 1

/*
 * ISA-based Watchdog Cards
 */
#define CONFIG_PCWATCHDOG_MODULE 1
#define CONFIG_MIXCOMWD_MODULE 1
#define CONFIG_WDT_MODULE 1
#undef CONFIG_WDT_501

/*
 * PCI-based Watchdog Cards
 */
#define CONFIG_PCIPCWATCHDOG_MODULE 1
#define CONFIG_WDTPCI_MODULE 1
#define CONFIG_WDT_501_PCI 1

/*
 * USB-based Watchdog Cards
 */
#define CONFIG_USBPCWATCHDOG_MODULE 1
#define CONFIG_HW_RANDOM_MODULE 1
#define CONFIG_NVRAM_MODULE 1
#define CONFIG_RTC 1
#define CONFIG_DTLK_MODULE 1
#define CONFIG_R3964_MODULE 1
#define CONFIG_APPLICOM_MODULE 1
#define CONFIG_SONYPI_MODULE 1

/*
 * Ftape, the floppy tape device driver
 */
#define CONFIG_FTAPE_MODULE 1
#define CONFIG_ZFTAPE_MODULE 1
#define CONFIG_ZFT_DFLT_BLK_SZ 10240

/*
 * The compressor will be built as a module only!
 */
#define CONFIG_ZFT_COMPRESSOR_MODULE 1
#define CONFIG_FT_NR_BUFFERS 3
#undef CONFIG_FT_PROC_FS
#define CONFIG_FT_NORMAL_DEBUG 1
#undef CONFIG_FT_FULL_DEBUG
#undef CONFIG_FT_NO_TRACE
#undef CONFIG_FT_NO_TRACE_AT_ALL

/*
 * Hardware configuration
 */
#define CONFIG_FT_STD_FDC 1
#undef CONFIG_FT_MACH2
#undef CONFIG_FT_PROBE_FC10
#undef CONFIG_FT_ALT_FDC
#define CONFIG_FT_FDC_THR 8
#define CONFIG_FT_FDC_MAX_RATE 2000
#define CONFIG_FT_ALPHA_CLOCK 0
#define CONFIG_AGP_MODULE 1
#define CONFIG_AGP_ALI_MODULE 1
#define CONFIG_AGP_ATI_MODULE 1
#define CONFIG_AGP_AMD_MODULE 1
#define CONFIG_AGP_AMD64_MODULE 1
#define CONFIG_AGP_INTEL_MODULE 1
#define CONFIG_AGP_NVIDIA_MODULE 1
#define CONFIG_AGP_SIS_MODULE 1
#define CONFIG_AGP_SWORKS_MODULE 1
#define CONFIG_AGP_VIA_MODULE 1
#define CONFIG_AGP_EFFICEON_MODULE 1
#define CONFIG_DRM_MODULE 1
#define CONFIG_DRM_TDFX_MODULE 1
#define CONFIG_DRM_R128_MODULE 1
#define CONFIG_DRM_RADEON_MODULE 1
#define CONFIG_DRM_I810_MODULE 1
#define CONFIG_DRM_I830_MODULE 1
#define CONFIG_DRM_I915_MODULE 1
#define CONFIG_DRM_MGA_MODULE 1
#define CONFIG_DRM_SIS_MODULE 1
#define CONFIG_DRM_VIA_MODULE 1
#define CONFIG_DRM_SAVAGE_MODULE 1

/*
 * PCMCIA character devices
 */
#define CONFIG_SYNCLINK_CS_MODULE 1
#define CONFIG_CARDMAN_4000_MODULE 1
#define CONFIG_CARDMAN_4040_MODULE 1
#define CONFIG_MWAVE_MODULE 1
#define CONFIG_SCx200_GPIO_MODULE 1
#define CONFIG_CS5535_GPIO_MODULE 1
#undef CONFIG_RAW_DRIVER
#undef CONFIG_HPET
#define CONFIG_HANGCHECK_TIMER_MODULE 1

/*
 * TPM devices
 */
#define CONFIG_TCG_TPM_MODULE 1
#define CONFIG_TCG_ATMEL_MODULE 1
#define CONFIG_TELCLOCK_MODULE 1

/*
 * I2C support
 */
#define CONFIG_I2C_MODULE 1
#define CONFIG_I2C_CHARDEV_MODULE 1

/*
 * I2C Algorithms
 */
#define CONFIG_I2C_ALGOBIT_MODULE 1
#define CONFIG_I2C_ALGOPCF_MODULE 1
#define CONFIG_I2C_ALGOPCA_MODULE 1

/*
 * I2C Hardware Bus support
 */
#define CONFIG_I2C_ALI1535_MODULE 1
#define CONFIG_I2C_ALI1563_MODULE 1
#define CONFIG_I2C_ALI15X3_MODULE 1
#define CONFIG_I2C_AMD756_MODULE 1
#define CONFIG_I2C_AMD756_S4882_MODULE 1
#define CONFIG_I2C_AMD8111_MODULE 1
#define CONFIG_I2C_ELEKTOR_MODULE 1
#define CONFIG_I2C_I801_MODULE 1
#define CONFIG_I2C_I810_MODULE 1
#define CONFIG_I2C_PIIX4_MODULE 1
#define CONFIG_I2C_ISA_MODULE 1
#define CONFIG_I2C_NFORCE2_MODULE 1
#define CONFIG_I2C_PARPORT_MODULE 1
#define CONFIG_I2C_PARPORT_LIGHT_MODULE 1
#define CONFIG_I2C_PROSAVAGE_MODULE 1
#define CONFIG_I2C_SAVAGE4_MODULE 1
#define CONFIG_SCx200_I2C_MODULE 1
#define CONFIG_SCx200_I2C_SCL 12
#define CONFIG_SCx200_I2C_SDA 13
#define CONFIG_SCx200_ACB_MODULE 1
#define CONFIG_I2C_SIS5595_MODULE 1
#define CONFIG_I2C_SIS630_MODULE 1
#define CONFIG_I2C_SIS96X_MODULE 1
#define CONFIG_I2C_STUB_MODULE 1
#define CONFIG_I2C_VIA_MODULE 1
#define CONFIG_I2C_VIAPRO_MODULE 1
#define CONFIG_I2C_VOODOO3_MODULE 1
#define CONFIG_I2C_PCA_ISA_MODULE 1

/*
 * Miscellaneous I2C Chip support
 */
#define CONFIG_SENSORS_DS1337_MODULE 1
#define CONFIG_SENSORS_DS1374_MODULE 1
#define CONFIG_SENSORS_EEPROM_MODULE 1
#define CONFIG_SENSORS_PCF8574_MODULE 1
#define CONFIG_SENSORS_PCA9539_MODULE 1
#define CONFIG_SENSORS_PCF8591_MODULE 1
#define CONFIG_SENSORS_MAX6875_MODULE 1
#undef CONFIG_I2C_DEBUG_CORE
#undef CONFIG_I2C_DEBUG_ALGO
#undef CONFIG_I2C_DEBUG_BUS
#undef CONFIG_I2C_DEBUG_CHIP

/*
 * SPI support
 */
#undef CONFIG_SPI
#undef CONFIG_SPI_MASTER

/*
 * Dallas's 1-wire bus
 */
#define CONFIG_W1_MODULE 1

/*
 * 1-wire Bus Masters
 */
#define CONFIG_W1_MASTER_MATROX_MODULE 1
#define CONFIG_W1_MASTER_DS9490_MODULE 1
#define CONFIG_W1_MASTER_DS9490_BRIDGE_MODULE 1
#define CONFIG_W1_MASTER_DS2482_MODULE 1

/*
 * 1-wire Slaves
 */
#define CONFIG_W1_SLAVE_THERM_MODULE 1
#define CONFIG_W1_SLAVE_SMEM_MODULE 1
#define CONFIG_W1_SLAVE_DS2433_MODULE 1

/*
 * Hardware Monitoring support
 */
#define CONFIG_HWMON_MODULE 1
#define CONFIG_HWMON_VID_MODULE 1
#define CONFIG_SENSORS_ADM1021_MODULE 1
#define CONFIG_SENSORS_ADM1025_MODULE 1
#define CONFIG_SENSORS_ADM1026_MODULE 1
#define CONFIG_SENSORS_ADM1031_MODULE 1
#define CONFIG_SENSORS_ADM9240_MODULE 1
#define CONFIG_SENSORS_ASB100_MODULE 1
#define CONFIG_SENSORS_ATXP1_MODULE 1
#define CONFIG_SENSORS_DS1621_MODULE 1
#define CONFIG_SENSORS_F71805F_MODULE 1
#define CONFIG_SENSORS_FSCHER_MODULE 1
#define CONFIG_SENSORS_FSCPOS_MODULE 1
#define CONFIG_SENSORS_GL518SM_MODULE 1
#define CONFIG_SENSORS_GL520SM_MODULE 1
#define CONFIG_SENSORS_IT87_MODULE 1
#define CONFIG_SENSORS_LM63_MODULE 1
#define CONFIG_SENSORS_LM75_MODULE 1
#define CONFIG_SENSORS_LM77_MODULE 1
#define CONFIG_SENSORS_LM78_MODULE 1
#define CONFIG_SENSORS_LM80_MODULE 1
#define CONFIG_SENSORS_LM83_MODULE 1
#define CONFIG_SENSORS_LM85_MODULE 1
#define CONFIG_SENSORS_LM87_MODULE 1
#define CONFIG_SENSORS_LM90_MODULE 1
#define CONFIG_SENSORS_LM92_MODULE 1
#define CONFIG_SENSORS_MAX1619_MODULE 1
#define CONFIG_SENSORS_PC87360_MODULE 1
#define CONFIG_SENSORS_SIS5595_MODULE 1
#define CONFIG_SENSORS_SMSC47M1_MODULE 1
#define CONFIG_SENSORS_SMSC47B397_MODULE 1
#define CONFIG_SENSORS_VIA686A_MODULE 1
#define CONFIG_SENSORS_VT8231_MODULE 1
#define CONFIG_SENSORS_W83781D_MODULE 1
#define CONFIG_SENSORS_W83792D_MODULE 1
#define CONFIG_SENSORS_W83L785TS_MODULE 1
#define CONFIG_SENSORS_W83627HF_MODULE 1
#define CONFIG_SENSORS_W83627EHF_MODULE 1
#define CONFIG_SENSORS_HDAPS_MODULE 1
#undef CONFIG_HWMON_DEBUG_CHIP

/*
 * Misc devices
 */
#define CONFIG_IBM_ASM_MODULE 1

/*
 * Multimedia devices
 */
#define CONFIG_VIDEO_DEV_MODULE 1
#define CONFIG_VIDEO_V4L1 1
#define CONFIG_VIDEO_V4L1_COMPAT 1
#define CONFIG_VIDEO_V4L2_MODULE 1

/*
 * Video Capture Adapters
 */

/*
 * Video Capture Adapters
 */
#undef CONFIG_VIDEO_ADV_DEBUG
#define CONFIG_VIDEO_VIVI_MODULE 1
#define CONFIG_VIDEO_BT848_MODULE 1
#define CONFIG_VIDEO_BT848_DVB 1
#define CONFIG_VIDEO_SAA6588_MODULE 1
#define CONFIG_VIDEO_PMS_MODULE 1
#define CONFIG_VIDEO_BWQCAM_MODULE 1
#define CONFIG_VIDEO_CQCAM_MODULE 1
#define CONFIG_VIDEO_W9966_MODULE 1
#define CONFIG_VIDEO_CPIA_MODULE 1
#define CONFIG_VIDEO_CPIA_PP_MODULE 1
#define CONFIG_VIDEO_CPIA_USB_MODULE 1
#define CONFIG_VIDEO_CPIA2_MODULE 1
#define CONFIG_VIDEO_SAA5246A_MODULE 1
#define CONFIG_VIDEO_SAA5249_MODULE 1
#define CONFIG_TUNER_3036_MODULE 1
#define CONFIG_VIDEO_STRADIS_MODULE 1
#define CONFIG_VIDEO_ZORAN_MODULE 1
#define CONFIG_VIDEO_ZORAN_BUZ_MODULE 1
#define CONFIG_VIDEO_ZORAN_DC10_MODULE 1
#define CONFIG_VIDEO_ZORAN_DC30_MODULE 1
#define CONFIG_VIDEO_ZORAN_LML33_MODULE 1
#define CONFIG_VIDEO_ZORAN_LML33R10_MODULE 1
#define CONFIG_VIDEO_MEYE_MODULE 1
#define CONFIG_VIDEO_SAA7134_MODULE 1
#undef CONFIG_VIDEO_SAA7134_ALSA
#define CONFIG_VIDEO_SAA7134_DVB_MODULE 1
#define CONFIG_VIDEO_SAA7134_DVB_ALL_FRONTENDS 1
#define CONFIG_VIDEO_MXB_MODULE 1
#define CONFIG_VIDEO_DPC_MODULE 1
#define CONFIG_VIDEO_HEXIUM_ORION_MODULE 1
#define CONFIG_VIDEO_HEXIUM_GEMINI_MODULE 1
#define CONFIG_VIDEO_CX88_VP3054_MODULE 1
#define CONFIG_VIDEO_CX88_MODULE 1
#undef CONFIG_VIDEO_CX88_ALSA
#define CONFIG_VIDEO_CX88_DVB_MODULE 1
#define CONFIG_VIDEO_CX88_DVB_ALL_FRONTENDS 1
#define CONFIG_VIDEO_OVCAMCHIP_MODULE 1

/*
 * Encoders and Decoders
 */
#define CONFIG_VIDEO_MSP3400_MODULE 1
#define CONFIG_VIDEO_CS53L32A_MODULE 1
#define CONFIG_VIDEO_WM8775_MODULE 1
#define CONFIG_VIDEO_WM8739_MODULE 1
#define CONFIG_VIDEO_CX25840_MODULE 1
#define CONFIG_VIDEO_SAA711X_MODULE 1
#define CONFIG_VIDEO_SAA7127_MODULE 1
#define CONFIG_VIDEO_UPD64031A_MODULE 1
#define CONFIG_VIDEO_UPD64083_MODULE 1

/*
 * V4L USB devices
 */
#define CONFIG_VIDEO_EM28XX_MODULE 1
#define CONFIG_USB_DSBR_MODULE 1
#define CONFIG_VIDEO_USBVIDEO_MODULE 1
#define CONFIG_USB_VICAM_MODULE 1
#define CONFIG_USB_IBMCAM_MODULE 1
#define CONFIG_USB_KONICAWC_MODULE 1
#define CONFIG_USB_ET61X251_MODULE 1
#define CONFIG_USB_OV511_MODULE 1
#define CONFIG_USB_SE401_MODULE 1
#define CONFIG_USB_SN9C102_MODULE 1
#define CONFIG_USB_STV680_MODULE 1
#define CONFIG_USB_W9968CF_MODULE 1
#define CONFIG_USB_ZC0301_MODULE 1
#define CONFIG_USB_PWC_MODULE 1

/*
 * Radio Adapters
 */
#define CONFIG_RADIO_CADET_MODULE 1
#define CONFIG_RADIO_RTRACK_MODULE 1
#define CONFIG_RADIO_RTRACK2_MODULE 1
#define CONFIG_RADIO_AZTECH_MODULE 1
#define CONFIG_RADIO_GEMTEK_MODULE 1
#define CONFIG_RADIO_GEMTEK_PCI_MODULE 1
#define CONFIG_RADIO_MAXIRADIO_MODULE 1
#define CONFIG_RADIO_MAESTRO_MODULE 1
#define CONFIG_RADIO_SF16FMI_MODULE 1
#define CONFIG_RADIO_SF16FMR2_MODULE 1
#define CONFIG_RADIO_TERRATEC_MODULE 1
#define CONFIG_RADIO_TRUST_MODULE 1
#define CONFIG_RADIO_TYPHOON_MODULE 1
#define CONFIG_RADIO_TYPHOON_PROC_FS 1
#define CONFIG_RADIO_ZOLTRIX_MODULE 1

/*
 * Digital Video Broadcasting Devices
 */
#define CONFIG_DVB 1
#define CONFIG_DVB_CORE_MODULE 1

/*
 * Supported SAA7146 based PCI Adapters
 */
#define CONFIG_DVB_AV7110_MODULE 1
#define CONFIG_DVB_AV7110_OSD 1
#define CONFIG_DVB_BUDGET_MODULE 1
#define CONFIG_DVB_BUDGET_CI_MODULE 1
#undef CONFIG_DVB_BUDGET_AV
#define CONFIG_DVB_BUDGET_PATCH_MODULE 1

/*
 * Supported USB Adapters
 */
#define CONFIG_DVB_USB_MODULE 1
#undef CONFIG_DVB_USB_DEBUG
#define CONFIG_DVB_USB_A800_MODULE 1
#define CONFIG_DVB_USB_DIBUSB_MB_MODULE 1
#undef CONFIG_DVB_USB_DIBUSB_MB_FAULTY
#define CONFIG_DVB_USB_DIBUSB_MC_MODULE 1
#define CONFIG_DVB_USB_UMT_010_MODULE 1
#define CONFIG_DVB_USB_CXUSB_MODULE 1
#define CONFIG_DVB_USB_DIGITV_MODULE 1
#define CONFIG_DVB_USB_VP7045_MODULE 1
#define CONFIG_DVB_USB_VP702X_MODULE 1
#define CONFIG_DVB_USB_NOVA_T_USB2_MODULE 1
#define CONFIG_DVB_USB_DTT200U_MODULE 1
#define CONFIG_DVB_TTUSB_BUDGET_MODULE 1
#define CONFIG_DVB_TTUSB_DEC_MODULE 1
#define CONFIG_DVB_CINERGYT2_MODULE 1
#define CONFIG_DVB_CINERGYT2_TUNING 1
#define CONFIG_DVB_CINERGYT2_STREAM_URB_COUNT 32
#define CONFIG_DVB_CINERGYT2_STREAM_BUF_SIZE 512
#define CONFIG_DVB_CINERGYT2_QUERY_INTERVAL 250
#undef CONFIG_DVB_CINERGYT2_ENABLE_RC_INPUT_DEVICE

/*
 * Supported FlexCopII (B2C2) Adapters
 */
#define CONFIG_DVB_B2C2_FLEXCOP_MODULE 1
#define CONFIG_DVB_B2C2_FLEXCOP_PCI_MODULE 1
#define CONFIG_DVB_B2C2_FLEXCOP_USB_MODULE 1
#undef CONFIG_DVB_B2C2_FLEXCOP_DEBUG

/*
 * Supported BT878 Adapters
 */
#define CONFIG_DVB_BT8XX_MODULE 1

/*
 * Supported Pluto2 Adapters
 */
#define CONFIG_DVB_PLUTO2_MODULE 1

/*
 * Supported DVB Frontends
 */

/*
 * Customise DVB Frontends
 */

/*
 * DVB-S (satellite) frontends
 */
#define CONFIG_DVB_STV0299_MODULE 1
#define CONFIG_DVB_CX24110_MODULE 1
#define CONFIG_DVB_CX24123_MODULE 1
#define CONFIG_DVB_TDA8083_MODULE 1
#define CONFIG_DVB_MT312_MODULE 1
#define CONFIG_DVB_VES1X93_MODULE 1
#define CONFIG_DVB_S5H1420_MODULE 1

/*
 * DVB-T (terrestrial) frontends
 */
#define CONFIG_DVB_SP8870_MODULE 1
#define CONFIG_DVB_SP887X_MODULE 1
#define CONFIG_DVB_CX22700_MODULE 1
#define CONFIG_DVB_CX22702_MODULE 1
#define CONFIG_DVB_L64781_MODULE 1
#define CONFIG_DVB_TDA1004X_MODULE 1
#define CONFIG_DVB_NXT6000_MODULE 1
#define CONFIG_DVB_MT352_MODULE 1
#define CONFIG_DVB_ZL10353_MODULE 1
#define CONFIG_DVB_DIB3000MB_MODULE 1
#define CONFIG_DVB_DIB3000MC_MODULE 1

/*
 * DVB-C (cable) frontends
 */
#define CONFIG_DVB_VES1820_MODULE 1
#define CONFIG_DVB_TDA10021_MODULE 1
#define CONFIG_DVB_STV0297_MODULE 1

/*
 * ATSC (North American/Korean Terresterial DTV) frontends
 */
#define CONFIG_DVB_NXT200X_MODULE 1
#define CONFIG_DVB_OR51211_MODULE 1
#define CONFIG_DVB_OR51132_MODULE 1
#define CONFIG_DVB_BCM3510_MODULE 1
#define CONFIG_DVB_LGDT330X_MODULE 1
#define CONFIG_VIDEO_SAA7146_MODULE 1
#define CONFIG_VIDEO_SAA7146_VV_MODULE 1
#define CONFIG_VIDEO_VIDEOBUF_MODULE 1
#define CONFIG_VIDEO_TUNER_MODULE 1
#define CONFIG_VIDEO_BUF_MODULE 1
#define CONFIG_VIDEO_BUF_DVB_MODULE 1
#define CONFIG_VIDEO_BTCX_MODULE 1
#define CONFIG_VIDEO_IR_MODULE 1
#define CONFIG_VIDEO_TVEEPROM_MODULE 1
#define CONFIG_USB_DABUSB_MODULE 1

/*
 * Graphics support
 */
#define CONFIG_FB 1
#define CONFIG_FB_CFB_FILLRECT 1
#define CONFIG_FB_CFB_COPYAREA 1
#define CONFIG_FB_CFB_IMAGEBLIT 1
#undef CONFIG_FB_MACMODES
#undef CONFIG_FB_FIRMWARE_EDID
#define CONFIG_FB_MODE_HELPERS 1
#define CONFIG_FB_TILEBLITTING 1
#define CONFIG_FB_CIRRUS_MODULE 1
#define CONFIG_FB_PM2_MODULE 1
#undef CONFIG_FB_PM2_FIFO_DISCONNECT
#define CONFIG_FB_CYBER2000_MODULE 1
#define CONFIG_FB_ARC_MODULE 1
#undef CONFIG_FB_ASILIANT
#undef CONFIG_FB_IMSTT
#define CONFIG_FB_VGA16_MODULE 1
#define CONFIG_FB_VESA 1
#define CONFIG_VIDEO_SELECT 1
#define CONFIG_FB_HGA_MODULE 1
#undef CONFIG_FB_HGA_ACCEL
#define CONFIG_FB_S1D13XXX_MODULE 1
#define CONFIG_FB_NVIDIA_MODULE 1
#define CONFIG_FB_NVIDIA_I2C 1
#define CONFIG_FB_RIVA_MODULE 1
#define CONFIG_FB_RIVA_I2C 1
#undef CONFIG_FB_RIVA_DEBUG
#define CONFIG_FB_I810_MODULE 1
#define CONFIG_FB_I810_GTF 1
#define CONFIG_FB_I810_I2C 1
#define CONFIG_FB_INTEL_MODULE 1
#undef CONFIG_FB_INTEL_DEBUG
#define CONFIG_FB_MATROX_MODULE 1
#define CONFIG_FB_MATROX_MILLENIUM 1
#define CONFIG_FB_MATROX_MYSTIQUE 1
#define CONFIG_FB_MATROX_G 1
#define CONFIG_FB_MATROX_I2C_MODULE 1
#define CONFIG_FB_MATROX_MAVEN_MODULE 1
#define CONFIG_FB_MATROX_MULTIHEAD 1
#define CONFIG_FB_RADEON_MODULE 1
#define CONFIG_FB_RADEON_I2C 1
#undef CONFIG_FB_RADEON_DEBUG
#define CONFIG_FB_ATY128_MODULE 1
#define CONFIG_FB_ATY_MODULE 1
#define CONFIG_FB_ATY_CT 1
#define CONFIG_FB_ATY_GENERIC_LCD 1
#define CONFIG_FB_ATY_GX 1
#define CONFIG_FB_SAVAGE_MODULE 1
#define CONFIG_FB_SAVAGE_I2C 1
#define CONFIG_FB_SAVAGE_ACCEL 1
#define CONFIG_FB_SIS_MODULE 1
#define CONFIG_FB_SIS_300 1
#define CONFIG_FB_SIS_315 1
#define CONFIG_FB_NEOMAGIC_MODULE 1
#define CONFIG_FB_KYRO_MODULE 1
#define CONFIG_FB_3DFX_MODULE 1
#undef CONFIG_FB_3DFX_ACCEL
#define CONFIG_FB_VOODOO1_MODULE 1
#define CONFIG_FB_CYBLA_MODULE 1
#define CONFIG_FB_TRIDENT_MODULE 1
#undef CONFIG_FB_TRIDENT_ACCEL
#define CONFIG_FB_GEODE 1
#define CONFIG_FB_GEODE_GX_MODULE 1
#define CONFIG_FB_GEODE_GX1_MODULE 1
#undef CONFIG_FB_VIRTUAL

/*
 * Console display driver support
 */
#define CONFIG_VGA_CONSOLE 1
#define CONFIG_VGACON_SOFT_SCROLLBACK 1
#define CONFIG_VGACON_SOFT_SCROLLBACK_SIZE 64
#define CONFIG_MDA_CONSOLE_MODULE 1
#define CONFIG_DUMMY_CONSOLE 1
#define CONFIG_FRAMEBUFFER_CONSOLE 1
#undef CONFIG_FRAMEBUFFER_CONSOLE_ROTATION
#define CONFIG_FONTS 1
#define CONFIG_FONT_8x8 1
#define CONFIG_FONT_8x16 1
#undef CONFIG_FONT_6x11
#undef CONFIG_FONT_7x14
#undef CONFIG_FONT_PEARL_8x8
#undef CONFIG_FONT_ACORN_8x8
#undef CONFIG_FONT_MINI_4x6
#undef CONFIG_FONT_SUN8x16
#undef CONFIG_FONT_SUN12x22
#undef CONFIG_FONT_10x18

/*
 * Logo configuration
 */
#define CONFIG_LOGO 1
#undef CONFIG_LOGO_LINUX_MONO
#undef CONFIG_LOGO_LINUX_VGA16
#define CONFIG_LOGO_LINUX_CLUT224 1
#define CONFIG_BACKLIGHT_LCD_SUPPORT 1
#define CONFIG_BACKLIGHT_CLASS_DEVICE_MODULE 1
#define CONFIG_BACKLIGHT_DEVICE 1
#define CONFIG_LCD_CLASS_DEVICE_MODULE 1
#define CONFIG_LCD_DEVICE 1

/*
 * Sound
 */
#define CONFIG_SOUND_MODULE 1

/*
 * Advanced Linux Sound Architecture
 */
#define CONFIG_SND_MODULE 1
#define CONFIG_SND_TIMER_MODULE 1
#define CONFIG_SND_PCM_MODULE 1
#define CONFIG_SND_HWDEP_MODULE 1
#define CONFIG_SND_RAWMIDI_MODULE 1
#define CONFIG_SND_SEQUENCER_MODULE 1
#define CONFIG_SND_SEQ_DUMMY_MODULE 1
#define CONFIG_SND_OSSEMUL 1
#define CONFIG_SND_MIXER_OSS_MODULE 1
#define CONFIG_SND_PCM_OSS_MODULE 1
#define CONFIG_SND_PCM_OSS_PLUGINS 1
#define CONFIG_SND_SEQUENCER_OSS 1
#define CONFIG_SND_RTCTIMER_MODULE 1
#define CONFIG_SND_SEQ_RTCTIMER_DEFAULT 1
#undef CONFIG_SND_DYNAMIC_MINORS
#define CONFIG_SND_SUPPORT_OLD_API 1
#define CONFIG_SND_VERBOSE_PROCFS 1
#undef CONFIG_SND_VERBOSE_PRINTK
#undef CONFIG_SND_DEBUG

/*
 * Generic devices
 */
#define CONFIG_SND_MPU401_UART_MODULE 1
#define CONFIG_SND_OPL3_LIB_MODULE 1
#define CONFIG_SND_OPL4_LIB_MODULE 1
#define CONFIG_SND_VX_LIB_MODULE 1
#define CONFIG_SND_AC97_CODEC_MODULE 1
#define CONFIG_SND_AC97_BUS_MODULE 1
#define CONFIG_SND_DUMMY_MODULE 1
#define CONFIG_SND_VIRMIDI_MODULE 1
#define CONFIG_SND_MTPAV_MODULE 1
#define CONFIG_SND_SERIAL_U16550_MODULE 1
#define CONFIG_SND_MPU401_MODULE 1

/*
 * ISA devices
 */
#define CONFIG_SND_AD1848_LIB_MODULE 1
#define CONFIG_SND_CS4231_LIB_MODULE 1
#define CONFIG_SND_ADLIB_MODULE 1
#define CONFIG_SND_AD1816A_MODULE 1
#define CONFIG_SND_AD1848_MODULE 1
#define CONFIG_SND_ALS100_MODULE 1
#define CONFIG_SND_AZT2320_MODULE 1
#define CONFIG_SND_CMI8330_MODULE 1
#define CONFIG_SND_CS4231_MODULE 1
#define CONFIG_SND_CS4232_MODULE 1
#define CONFIG_SND_CS4236_MODULE 1
#define CONFIG_SND_DT019X_MODULE 1
#define CONFIG_SND_ES968_MODULE 1
#define CONFIG_SND_ES1688_MODULE 1
#define CONFIG_SND_ES18XX_MODULE 1
#define CONFIG_SND_GUS_SYNTH_MODULE 1
#define CONFIG_SND_GUSCLASSIC_MODULE 1
#define CONFIG_SND_GUSEXTREME_MODULE 1
#define CONFIG_SND_GUSMAX_MODULE 1
#define CONFIG_SND_INTERWAVE_MODULE 1
#define CONFIG_SND_INTERWAVE_STB_MODULE 1
#define CONFIG_SND_OPL3SA2_MODULE 1
#define CONFIG_SND_OPTI92X_AD1848_MODULE 1
#define CONFIG_SND_OPTI92X_CS4231_MODULE 1
#define CONFIG_SND_OPTI93X_MODULE 1
#define CONFIG_SND_MIRO_MODULE 1
#define CONFIG_SND_SB8_MODULE 1
#define CONFIG_SND_SB16_MODULE 1
#define CONFIG_SND_SBAWE_MODULE 1
#define CONFIG_SND_SB16_CSP 1
#define CONFIG_SND_SGALAXY_MODULE 1
#define CONFIG_SND_SSCAPE_MODULE 1
#define CONFIG_SND_WAVEFRONT_MODULE 1

/*
 * PCI devices
 */
#define CONFIG_SND_AD1889_MODULE 1
#define CONFIG_SND_ALS300_MODULE 1
#define CONFIG_SND_ALS4000_MODULE 1
#define CONFIG_SND_ALI5451_MODULE 1
#define CONFIG_SND_ATIIXP_MODULE 1
#define CONFIG_SND_ATIIXP_MODEM_MODULE 1
#define CONFIG_SND_AU8810_MODULE 1
#define CONFIG_SND_AU8820_MODULE 1
#define CONFIG_SND_AU8830_MODULE 1
#define CONFIG_SND_AZT3328_MODULE 1
#define CONFIG_SND_BT87X_MODULE 1
#undef CONFIG_SND_BT87X_OVERCLOCK
#define CONFIG_SND_CA0106_MODULE 1
#define CONFIG_SND_CMIPCI_MODULE 1
#define CONFIG_SND_CS4281_MODULE 1
#define CONFIG_SND_CS46XX_MODULE 1
#define CONFIG_SND_CS46XX_NEW_DSP 1
#define CONFIG_SND_CS5535AUDIO_MODULE 1
#define CONFIG_SND_EMU10K1_MODULE 1
#define CONFIG_SND_EMU10K1X_MODULE 1
#define CONFIG_SND_ENS1370_MODULE 1
#define CONFIG_SND_ENS1371_MODULE 1
#define CONFIG_SND_ES1938_MODULE 1
#define CONFIG_SND_ES1968_MODULE 1
#define CONFIG_SND_FM801_MODULE 1
#define CONFIG_SND_FM801_TEA575X_BOOL 1
#define CONFIG_SND_FM801_TEA575X_MODULE 1
#define CONFIG_SND_HDA_INTEL_MODULE 1
#define CONFIG_SND_HDSP_MODULE 1
#define CONFIG_SND_HDSPM_MODULE 1
#define CONFIG_SND_ICE1712_MODULE 1
#define CONFIG_SND_ICE1724_MODULE 1
#define CONFIG_SND_INTEL8X0_MODULE 1
#define CONFIG_SND_INTEL8X0M_MODULE 1
#define CONFIG_SND_KORG1212_MODULE 1
#define CONFIG_SND_MAESTRO3_MODULE 1
#define CONFIG_SND_MIXART_MODULE 1
#define CONFIG_SND_NM256_MODULE 1
#define CONFIG_SND_PCXHR_MODULE 1
#define CONFIG_SND_RIPTIDE_MODULE 1
#define CONFIG_SND_RME32_MODULE 1
#define CONFIG_SND_RME96_MODULE 1
#define CONFIG_SND_RME9652_MODULE 1
#define CONFIG_SND_SONICVIBES_MODULE 1
#define CONFIG_SND_TRIDENT_MODULE 1
#define CONFIG_SND_VIA82XX_MODULE 1
#define CONFIG_SND_VIA82XX_MODEM_MODULE 1
#define CONFIG_SND_VX222_MODULE 1
#define CONFIG_SND_YMFPCI_MODULE 1

/*
 * USB devices
 */
#define CONFIG_SND_USB_AUDIO_MODULE 1
#define CONFIG_SND_USB_USX2Y_MODULE 1

/*
 * PCMCIA devices
 */
#define CONFIG_SND_VXPOCKET_MODULE 1
#define CONFIG_SND_PDAUDIOCF_MODULE 1

/*
 * Open Sound System
 */
#undef CONFIG_SOUND_PRIME

/*
 * USB support
 */
#define CONFIG_USB_ARCH_HAS_HCD 1
#define CONFIG_USB_ARCH_HAS_OHCI 1
#define CONFIG_USB_ARCH_HAS_EHCI 1
#define CONFIG_USB 1
#undef CONFIG_USB_DEBUG

/*
 * Miscellaneous USB options
 */
#define CONFIG_USB_DEVICEFS 1
#undef CONFIG_USB_BANDWIDTH
#undef CONFIG_USB_DYNAMIC_MINORS
#undef CONFIG_USB_SUSPEND
#undef CONFIG_USB_OTG

/*
 * USB Host Controller Drivers
 */
#define CONFIG_USB_EHCI_HCD_MODULE 1
#define CONFIG_USB_EHCI_SPLIT_ISO 1
#define CONFIG_USB_EHCI_ROOT_HUB_TT 1
#define CONFIG_USB_ISP116X_HCD_MODULE 1
#define CONFIG_USB_OHCI_HCD_MODULE 1
#undef CONFIG_USB_OHCI_BIG_ENDIAN
#define CONFIG_USB_OHCI_LITTLE_ENDIAN 1
#define CONFIG_USB_UHCI_HCD_MODULE 1
#define CONFIG_USB_SL811_HCD_MODULE 1
#define CONFIG_USB_SL811_CS_MODULE 1

/*
 * USB Device Class drivers
 */
#define CONFIG_USB_ACM_MODULE 1
#define CONFIG_USB_PRINTER_MODULE 1

/*
 * NOTE: USB_STORAGE enables SCSI, and 'SCSI disk support'
 */

/*
 * may also be needed; see USB_STORAGE Help for more information
 */
#define CONFIG_USB_STORAGE_MODULE 1
#undef CONFIG_USB_STORAGE_DEBUG
#define CONFIG_USB_STORAGE_DATAFAB 1
#define CONFIG_USB_STORAGE_FREECOM 1
#define CONFIG_USB_STORAGE_ISD200 1
#define CONFIG_USB_STORAGE_DPCM 1
#define CONFIG_USB_STORAGE_USBAT 1
#define CONFIG_USB_STORAGE_SDDR09 1
#define CONFIG_USB_STORAGE_SDDR55 1
#define CONFIG_USB_STORAGE_JUMPSHOT 1
#define CONFIG_USB_STORAGE_ALAUDA 1
#undef CONFIG_USB_LIBUSUAL

/*
 * USB Input Devices
 */
#define CONFIG_USB_HID 1
#define CONFIG_USB_HIDINPUT 1
#undef CONFIG_USB_HIDINPUT_POWERBOOK
#define CONFIG_HID_FF 1
#define CONFIG_HID_PID 1
#define CONFIG_LOGITECH_FF 1
#define CONFIG_THRUSTMASTER_FF 1
#define CONFIG_USB_HIDDEV 1
#define CONFIG_USB_AIPTEK_MODULE 1
#define CONFIG_USB_WACOM_MODULE 1
#define CONFIG_USB_ACECAD_MODULE 1
#define CONFIG_USB_KBTAB_MODULE 1
#define CONFIG_USB_POWERMATE_MODULE 1
#define CONFIG_USB_TOUCHSCREEN_MODULE 1
#define CONFIG_USB_TOUCHSCREEN_EGALAX 1
#define CONFIG_USB_TOUCHSCREEN_PANJIT 1
#define CONFIG_USB_TOUCHSCREEN_3M 1
#define CONFIG_USB_TOUCHSCREEN_ITM 1
#define CONFIG_USB_YEALINK_MODULE 1
#define CONFIG_USB_XPAD_MODULE 1
#define CONFIG_USB_ATI_REMOTE_MODULE 1
#define CONFIG_USB_ATI_REMOTE2_MODULE 1
#define CONFIG_USB_KEYSPAN_REMOTE_MODULE 1
#define CONFIG_USB_APPLETOUCH_MODULE 1

/*
 * USB Imaging devices
 */
#define CONFIG_USB_MDC800_MODULE 1
#define CONFIG_USB_MICROTEK_MODULE 1

/*
 * USB Network Adapters
 */
#define CONFIG_USB_CATC_MODULE 1
#define CONFIG_USB_KAWETH_MODULE 1
#define CONFIG_USB_PEGASUS_MODULE 1
#define CONFIG_USB_RTL8150_MODULE 1
#define CONFIG_USB_USBNET_MODULE 1
#define CONFIG_USB_NET_AX8817X_MODULE 1
#define CONFIG_USB_NET_CDCETHER_MODULE 1
#define CONFIG_USB_NET_GL620A_MODULE 1
#define CONFIG_USB_NET_NET1080_MODULE 1
#define CONFIG_USB_NET_PLUSB_MODULE 1
#define CONFIG_USB_NET_RNDIS_HOST_MODULE 1
#define CONFIG_USB_NET_CDC_SUBSET_MODULE 1
#define CONFIG_USB_ALI_M5632 1
#define CONFIG_USB_AN2720 1
#define CONFIG_USB_BELKIN 1
#define CONFIG_USB_ARMLINUX 1
#undef CONFIG_USB_EPSON2888
#define CONFIG_USB_NET_ZAURUS_MODULE 1
#define CONFIG_USB_ZD1201_MODULE 1
#define CONFIG_USB_MON 1

/*
 * USB port drivers
 */
#define CONFIG_USB_USS720_MODULE 1

/*
 * USB Serial Converter support
 */
#define CONFIG_USB_SERIAL_MODULE 1
#define CONFIG_USB_SERIAL_GENERIC 1
#define CONFIG_USB_SERIAL_AIRPRIME_MODULE 1
#define CONFIG_USB_SERIAL_ANYDATA_MODULE 1
#define CONFIG_USB_SERIAL_ARK3116_MODULE 1
#define CONFIG_USB_SERIAL_BELKIN_MODULE 1
#define CONFIG_USB_SERIAL_WHITEHEAT_MODULE 1
#define CONFIG_USB_SERIAL_DIGI_ACCELEPORT_MODULE 1
#define CONFIG_USB_SERIAL_CP2101_MODULE 1
#define CONFIG_USB_SERIAL_CYPRESS_M8_MODULE 1
#define CONFIG_USB_SERIAL_EMPEG_MODULE 1
#define CONFIG_USB_SERIAL_FTDI_SIO_MODULE 1
#define CONFIG_USB_SERIAL_FUNSOFT_MODULE 1
#define CONFIG_USB_SERIAL_VISOR_MODULE 1
#define CONFIG_USB_SERIAL_IPAQ_MODULE 1
#define CONFIG_USB_SERIAL_IR_MODULE 1
#define CONFIG_USB_SERIAL_EDGEPORT_MODULE 1
#define CONFIG_USB_SERIAL_EDGEPORT_TI_MODULE 1
#define CONFIG_USB_SERIAL_GARMIN_MODULE 1
#define CONFIG_USB_SERIAL_IPW_MODULE 1
#define CONFIG_USB_SERIAL_KEYSPAN_PDA_MODULE 1
#define CONFIG_USB_SERIAL_KEYSPAN_MODULE 1
#define CONFIG_USB_SERIAL_KEYSPAN_MPR 1
#define CONFIG_USB_SERIAL_KEYSPAN_USA28 1
#define CONFIG_USB_SERIAL_KEYSPAN_USA28X 1
#define CONFIG_USB_SERIAL_KEYSPAN_USA28XA 1
#define CONFIG_USB_SERIAL_KEYSPAN_USA28XB 1
#define CONFIG_USB_SERIAL_KEYSPAN_USA19 1
#define CONFIG_USB_SERIAL_KEYSPAN_USA18X 1
#define CONFIG_USB_SERIAL_KEYSPAN_USA19W 1
#define CONFIG_USB_SERIAL_KEYSPAN_USA19QW 1
#define CONFIG_USB_SERIAL_KEYSPAN_USA19QI 1
#define CONFIG_USB_SERIAL_KEYSPAN_USA49W 1
#define CONFIG_USB_SERIAL_KEYSPAN_USA49WLC 1
#define CONFIG_USB_SERIAL_KLSI_MODULE 1
#define CONFIG_USB_SERIAL_KOBIL_SCT_MODULE 1
#define CONFIG_USB_SERIAL_MCT_U232_MODULE 1
#define CONFIG_USB_SERIAL_NAVMAN_MODULE 1
#define CONFIG_USB_SERIAL_PL2303_MODULE 1
#define CONFIG_USB_SERIAL_HP4X_MODULE 1
#define CONFIG_USB_SERIAL_SAFE_MODULE 1
#define CONFIG_USB_SERIAL_SAFE_PADDED 1
#define CONFIG_USB_SERIAL_TI_MODULE 1
#define CONFIG_USB_SERIAL_CYBERJACK_MODULE 1
#define CONFIG_USB_SERIAL_XIRCOM_MODULE 1
#define CONFIG_USB_SERIAL_OPTION_MODULE 1
#define CONFIG_USB_SERIAL_OMNINET_MODULE 1
#define CONFIG_USB_EZUSB 1

/*
 * USB Miscellaneous drivers
 */
#define CONFIG_USB_EMI62_MODULE 1
#define CONFIG_USB_EMI26_MODULE 1
#define CONFIG_USB_AUERSWALD_MODULE 1
#define CONFIG_USB_RIO500_MODULE 1
#define CONFIG_USB_LEGOTOWER_MODULE 1
#define CONFIG_USB_LCD_MODULE 1
#define CONFIG_USB_LED_MODULE 1
#define CONFIG_USB_CYTHERM_MODULE 1
#define CONFIG_USB_PHIDGETKIT_MODULE 1
#define CONFIG_USB_PHIDGETSERVO_MODULE 1
#define CONFIG_USB_IDMOUSE_MODULE 1
#define CONFIG_USB_SISUSBVGA_MODULE 1
#define CONFIG_USB_SISUSBVGA_CON 1
#define CONFIG_USB_LD_MODULE 1
#define CONFIG_USB_TEST_MODULE 1

/*
 * USB DSL modem support
 */
#define CONFIG_USB_ATM_MODULE 1
#define CONFIG_USB_SPEEDTOUCH_MODULE 1
#define CONFIG_USB_CXACRU_MODULE 1
#define CONFIG_USB_UEAGLEATM_MODULE 1
#define CONFIG_USB_XUSBATM_MODULE 1

/*
 * USB Gadget Support
 */
#undef CONFIG_USB_GADGET

/*
 * MMC/SD Card support
 */
#define CONFIG_MMC_MODULE 1
#undef CONFIG_MMC_DEBUG
#define CONFIG_MMC_BLOCK_MODULE 1
#define CONFIG_MMC_SDHCI_MODULE 1
#define CONFIG_MMC_WBSD_MODULE 1

/*
 * LED devices
 */
#define CONFIG_NEW_LEDS 1
#define CONFIG_LEDS_CLASS_MODULE 1

/*
 * LED drivers
 */

/*
 * LED Triggers
 */
#define CONFIG_LEDS_TRIGGERS 1
#define CONFIG_LEDS_TRIGGER_TIMER_MODULE 1
#define CONFIG_LEDS_TRIGGER_IDE_DISK 1

/*
 * InfiniBand support
 */
#define CONFIG_INFINIBAND_MODULE 1
#define CONFIG_INFINIBAND_USER_MAD_MODULE 1
#define CONFIG_INFINIBAND_USER_ACCESS_MODULE 1
#define CONFIG_INFINIBAND_MTHCA_MODULE 1
#define CONFIG_INFINIBAND_MTHCA_DEBUG 1
#define CONFIG_INFINIBAND_IPOIB_MODULE 1
#define CONFIG_INFINIBAND_IPOIB_DEBUG 1
#undef CONFIG_INFINIBAND_IPOIB_DEBUG_DATA
#define CONFIG_INFINIBAND_SRP_MODULE 1

/*
 * EDAC - error detection and reporting (RAS) (EXPERIMENTAL)
 */
#undef CONFIG_EDAC

/*
 * Real Time Clock
 */
#define CONFIG_RTC_LIB_MODULE 1
#define CONFIG_RTC_CLASS_MODULE 1

/*
 * RTC interfaces
 */
#define CONFIG_RTC_INTF_SYSFS_MODULE 1
#define CONFIG_RTC_INTF_PROC_MODULE 1
#define CONFIG_RTC_INTF_DEV_MODULE 1

/*
 * RTC drivers
 */
#define CONFIG_RTC_DRV_X1205_MODULE 1
#define CONFIG_RTC_DRV_DS1672_MODULE 1
#define CONFIG_RTC_DRV_PCF8563_MODULE 1
#define CONFIG_RTC_DRV_RS5C372_MODULE 1
#define CONFIG_RTC_DRV_M48T86_MODULE 1
#define CONFIG_RTC_DRV_TEST_MODULE 1

/*
 * File systems
 */
#define CONFIG_EXT2_FS 1
#undef CONFIG_EXT2_FS_XATTR
#undef CONFIG_EXT2_FS_XIP
#define CONFIG_EXT3_FS_MODULE 1
#define CONFIG_EXT3_FS_XATTR 1
#define CONFIG_EXT3_FS_POSIX_ACL 1
#define CONFIG_EXT3_FS_SECURITY 1
#define CONFIG_JBD_MODULE 1
#undef CONFIG_JBD_DEBUG
#define CONFIG_FS_MBCACHE 1
#define CONFIG_REISERFS_FS_MODULE 1
#undef CONFIG_REISERFS_CHECK
#undef CONFIG_REISERFS_PROC_INFO
#define CONFIG_REISERFS_FS_XATTR 1
#define CONFIG_REISERFS_FS_POSIX_ACL 1
#define CONFIG_REISERFS_FS_SECURITY 1
#define CONFIG_JFS_FS_MODULE 1
#define CONFIG_JFS_POSIX_ACL 1
#define CONFIG_JFS_SECURITY 1
#undef CONFIG_JFS_DEBUG
#undef CONFIG_JFS_STATISTICS
#define CONFIG_FS_POSIX_ACL 1
#define CONFIG_XFS_FS_MODULE 1
#define CONFIG_XFS_EXPORT 1
#define CONFIG_XFS_QUOTA 1
#define CONFIG_XFS_SECURITY 1
#define CONFIG_XFS_POSIX_ACL 1
#undef CONFIG_XFS_RT
#define CONFIG_OCFS2_FS_MODULE 1
#define CONFIG_MINIX_FS_MODULE 1
#define CONFIG_ROMFS_FS_MODULE 1
#define CONFIG_INOTIFY 1
#define CONFIG_QUOTA 1
#define CONFIG_QFMT_V1_MODULE 1
#define CONFIG_QFMT_V2_MODULE 1
#define CONFIG_QUOTACTL 1
#define CONFIG_DNOTIFY 1
#define CONFIG_AUTOFS_FS_MODULE 1
#define CONFIG_AUTOFS4_FS_MODULE 1
#define CONFIG_FUSE_FS_MODULE 1

/*
 * CD-ROM/DVD Filesystems
 */
#define CONFIG_ISO9660_FS_MODULE 1
#define CONFIG_JOLIET 1
#define CONFIG_ZISOFS 1
#define CONFIG_ZISOFS_FS_MODULE 1
#define CONFIG_UDF_FS_MODULE 1
#define CONFIG_UDF_NLS 1

/*
 * DOS/FAT/NT Filesystems
 */
#define CONFIG_FAT_FS_MODULE 1
#define CONFIG_MSDOS_FS_MODULE 1
#define CONFIG_VFAT_FS_MODULE 1
#define CONFIG_FAT_DEFAULT_CODEPAGE 437
#define CONFIG_FAT_DEFAULT_IOCHARSET "iso8859-1"
#define CONFIG_NTFS_FS_MODULE 1
#undef CONFIG_NTFS_DEBUG
#define CONFIG_NTFS_RW 1

/*
 * Pseudo filesystems
 */
#define CONFIG_PROC_FS 1
#define CONFIG_PROC_KCORE 1
#define CONFIG_SYSFS 1
#define CONFIG_TMPFS 1
#undef CONFIG_HUGETLBFS
#undef CONFIG_HUGETLB_PAGE
#define CONFIG_RAMFS 1
#define CONFIG_CONFIGFS_FS_MODULE 1

/*
 * Miscellaneous filesystems
 */
#define CONFIG_ADFS_FS_MODULE 1
#undef CONFIG_ADFS_FS_RW
#define CONFIG_AFFS_FS_MODULE 1
#define CONFIG_HFS_FS_MODULE 1
#define CONFIG_HFSPLUS_FS_MODULE 1
#define CONFIG_BEFS_FS_MODULE 1
#undef CONFIG_BEFS_DEBUG
#define CONFIG_BFS_FS_MODULE 1
#define CONFIG_EFS_FS_MODULE 1
#define CONFIG_CRAMFS_MODULE 1
#define CONFIG_VXFS_FS_MODULE 1
#define CONFIG_HPFS_FS_MODULE 1
#define CONFIG_QNX4FS_FS_MODULE 1
#define CONFIG_SYSV_FS_MODULE 1
#define CONFIG_UFS_FS_MODULE 1

/*
 * Network File Systems
 */
#define CONFIG_NFS_FS_MODULE 1
#define CONFIG_NFS_V3 1
#undef CONFIG_NFS_V3_ACL
#define CONFIG_NFS_V4 1
#define CONFIG_NFS_DIRECTIO 1
#define CONFIG_NFSD_MODULE 1
#define CONFIG_NFSD_V3 1
#undef CONFIG_NFSD_V3_ACL
#define CONFIG_NFSD_V4 1
#define CONFIG_NFSD_TCP 1
#define CONFIG_LOCKD_MODULE 1
#define CONFIG_LOCKD_V4 1
#define CONFIG_EXPORTFS_MODULE 1
#define CONFIG_NFS_COMMON 1
#define CONFIG_SUNRPC_MODULE 1
#define CONFIG_SUNRPC_GSS_MODULE 1
#define CONFIG_RPCSEC_GSS_KRB5_MODULE 1
#define CONFIG_RPCSEC_GSS_SPKM3_MODULE 1
#define CONFIG_SMB_FS_MODULE 1
#undef CONFIG_SMB_NLS_DEFAULT
#define CONFIG_CIFS_MODULE 1
#undef CONFIG_CIFS_STATS
#undef CONFIG_CIFS_XATTR
#undef CONFIG_CIFS_EXPERIMENTAL
#define CONFIG_NCP_FS_MODULE 1
#define CONFIG_NCPFS_PACKET_SIGNING 1
#define CONFIG_NCPFS_IOCTL_LOCKING 1
#define CONFIG_NCPFS_STRONG 1
#define CONFIG_NCPFS_NFS_NS 1
#define CONFIG_NCPFS_OS2_NS 1
#define CONFIG_NCPFS_SMALLDOS 1
#define CONFIG_NCPFS_NLS 1
#define CONFIG_NCPFS_EXTRAS 1
#define CONFIG_CODA_FS_MODULE 1
#undef CONFIG_CODA_FS_OLD_API
#define CONFIG_AFS_FS_MODULE 1
#define CONFIG_RXRPC_MODULE 1
#undef CONFIG_9P_FS

/*
 * Partition Types
 */
#define CONFIG_PARTITION_ADVANCED 1
#undef CONFIG_ACORN_PARTITION
#undef CONFIG_OSF_PARTITION
#undef CONFIG_AMIGA_PARTITION
#undef CONFIG_ATARI_PARTITION
#define CONFIG_MAC_PARTITION 1
#define CONFIG_MSDOS_PARTITION 1
#define CONFIG_BSD_DISKLABEL 1
#undef CONFIG_MINIX_SUBPARTITION
#define CONFIG_SOLARIS_X86_PARTITION 1
#undef CONFIG_UNIXWARE_DISKLABEL
#undef CONFIG_LDM_PARTITION
#undef CONFIG_SGI_PARTITION
#undef CONFIG_ULTRIX_PARTITION
#undef CONFIG_SUN_PARTITION
#define CONFIG_KARMA_PARTITION 1
#undef CONFIG_EFI_PARTITION

/*
 * Native Language Support
 */
#define CONFIG_NLS 1
#define CONFIG_NLS_DEFAULT "utf8"
#define CONFIG_NLS_CODEPAGE_437_MODULE 1
#define CONFIG_NLS_CODEPAGE_737_MODULE 1
#define CONFIG_NLS_CODEPAGE_775_MODULE 1
#define CONFIG_NLS_CODEPAGE_850_MODULE 1
#define CONFIG_NLS_CODEPAGE_852_MODULE 1
#define CONFIG_NLS_CODEPAGE_855_MODULE 1
#define CONFIG_NLS_CODEPAGE_857_MODULE 1
#define CONFIG_NLS_CODEPAGE_860_MODULE 1
#define CONFIG_NLS_CODEPAGE_861_MODULE 1
#define CONFIG_NLS_CODEPAGE_862_MODULE 1
#define CONFIG_NLS_CODEPAGE_863_MODULE 1
#define CONFIG_NLS_CODEPAGE_864_MODULE 1
#define CONFIG_NLS_CODEPAGE_865_MODULE 1
#define CONFIG_NLS_CODEPAGE_866_MODULE 1
#define CONFIG_NLS_CODEPAGE_869_MODULE 1
#define CONFIG_NLS_CODEPAGE_936_MODULE 1
#define CONFIG_NLS_CODEPAGE_950_MODULE 1
#define CONFIG_NLS_CODEPAGE_932_MODULE 1
#define CONFIG_NLS_CODEPAGE_949_MODULE 1
#define CONFIG_NLS_CODEPAGE_874_MODULE 1
#define CONFIG_NLS_ISO8859_8_MODULE 1
#define CONFIG_NLS_CODEPAGE_1250_MODULE 1
#define CONFIG_NLS_CODEPAGE_1251_MODULE 1
#define CONFIG_NLS_ASCII_MODULE 1
#define CONFIG_NLS_ISO8859_1_MODULE 1
#define CONFIG_NLS_ISO8859_2_MODULE 1
#define CONFIG_NLS_ISO8859_3_MODULE 1
#define CONFIG_NLS_ISO8859_4_MODULE 1
#define CONFIG_NLS_ISO8859_5_MODULE 1
#define CONFIG_NLS_ISO8859_6_MODULE 1
#define CONFIG_NLS_ISO8859_7_MODULE 1
#define CONFIG_NLS_ISO8859_9_MODULE 1
#define CONFIG_NLS_ISO8859_13_MODULE 1
#define CONFIG_NLS_ISO8859_14_MODULE 1
#define CONFIG_NLS_ISO8859_15_MODULE 1
#define CONFIG_NLS_KOI8_R_MODULE 1
#define CONFIG_NLS_KOI8_U_MODULE 1
#define CONFIG_NLS_UTF8_MODULE 1

/*
 * Instrumentation Support
 */
#undef CONFIG_PROFILING
#undef CONFIG_KPROBES

/*
 * Kernel hacking
 */
#undef CONFIG_PRINTK_TIME
#undef CONFIG_MAGIC_SYSRQ
#undef CONFIG_DEBUG_KERNEL
#define CONFIG_LOG_BUF_SHIFT 14
#define CONFIG_DEBUG_BUGVERBOSE 1
#undef CONFIG_DEBUG_FS
#undef CONFIG_UNWIND_INFO
#define CONFIG_EARLY_PRINTK 1
#define CONFIG_STACK_BACKTRACE_COLS 2
#define CONFIG_DOUBLEFAULT 1

/*
 * Security options
 */
#undef CONFIG_KEYS
#define CONFIG_SECURITY 1
#define CONFIG_SECURITY_NETWORK 1
#undef CONFIG_SECURITY_NETWORK_XFRM
#define CONFIG_SECURITY_CAPABILITIES_MODULE 1
#define CONFIG_SECURITY_ROOTPLUG_MODULE 1
#define CONFIG_SECURITY_SECLVL_MODULE 1

/*
 * Cryptographic options
 */
#define CONFIG_CRYPTO 1
#define CONFIG_CRYPTO_HMAC 1
#define CONFIG_CRYPTO_NULL_MODULE 1
#define CONFIG_CRYPTO_MD4_MODULE 1
#define CONFIG_CRYPTO_MD5 1
#define CONFIG_CRYPTO_SHA1_MODULE 1
#define CONFIG_CRYPTO_SHA256_MODULE 1
#define CONFIG_CRYPTO_SHA512_MODULE 1
#define CONFIG_CRYPTO_WP512_MODULE 1
#define CONFIG_CRYPTO_TGR192_MODULE 1
#define CONFIG_CRYPTO_DES_MODULE 1
#define CONFIG_CRYPTO_BLOWFISH_MODULE 1
#define CONFIG_CRYPTO_TWOFISH_MODULE 1
#define CONFIG_CRYPTO_SERPENT_MODULE 1
#define CONFIG_CRYPTO_AES_MODULE 1
#define CONFIG_CRYPTO_AES_586_MODULE 1
#define CONFIG_CRYPTO_CAST5_MODULE 1
#define CONFIG_CRYPTO_CAST6_MODULE 1
#define CONFIG_CRYPTO_TEA_MODULE 1
#define CONFIG_CRYPTO_ARC4_MODULE 1
#define CONFIG_CRYPTO_KHAZAD_MODULE 1
#define CONFIG_CRYPTO_ANUBIS_MODULE 1
#define CONFIG_CRYPTO_DEFLATE_MODULE 1
#define CONFIG_CRYPTO_MICHAEL_MIC_MODULE 1
#define CONFIG_CRYPTO_CRC32C_MODULE 1
#define CONFIG_CRYPTO_TEST_MODULE 1

/*
 * Hardware crypto devices
 */
#define CONFIG_CRYPTO_DEV_PADLOCK_MODULE 1
#define CONFIG_CRYPTO_DEV_PADLOCK_AES 1

/*
 * Library routines
 */
#define CONFIG_CRC_CCITT_MODULE 1
#define CONFIG_CRC16_MODULE 1
#define CONFIG_CRC32 1
#define CONFIG_LIBCRC32C_MODULE 1
#define CONFIG_ZLIB_INFLATE_MODULE 1
#define CONFIG_ZLIB_DEFLATE_MODULE 1
#define CONFIG_TEXTSEARCH 1
#define CONFIG_TEXTSEARCH_KMP_MODULE 1
#define CONFIG_TEXTSEARCH_BM_MODULE 1
#define CONFIG_TEXTSEARCH_FSM_MODULE 1
#define CONFIG_GENERIC_HARDIRQS 1
#define CONFIG_GENERIC_IRQ_PROBE 1
#define CONFIG_X86_BIOS_REBOOT 1
#define CONFIG_KTIME_SCALAR 1
